/* latex_menu.c generated by valac 0.21.2.9-2b15d, the Vala compiler
 * generated from latex_menu.vala, do not modify */

/*
 * This file is part of LaTeXila.
 *
 * Copyright © 2010-2011 Sébastien Wilmet
 *
 * LaTeXila is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * LaTeXila is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with LaTeXila.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include "config.h"
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gtksourceview/gtksource.h>


#define TYPE_LATEX_MENU (latex_menu_get_type ())
#define LATEX_MENU(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LATEX_MENU, LatexMenu))
#define LATEX_MENU_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LATEX_MENU, LatexMenuClass))
#define IS_LATEX_MENU(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LATEX_MENU))
#define IS_LATEX_MENU_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LATEX_MENU))
#define LATEX_MENU_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LATEX_MENU, LatexMenuClass))

typedef struct _LatexMenu LatexMenu;
typedef struct _LatexMenuClass LatexMenuClass;
typedef struct _LatexMenuPrivate LatexMenuPrivate;

#define TYPE_MAIN_WINDOW (main_window_get_type ())
#define MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MAIN_WINDOW, MainWindow))
#define MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MAIN_WINDOW, MainWindowClass))
#define IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MAIN_WINDOW))
#define IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MAIN_WINDOW))
#define MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MAIN_WINDOW, MainWindowClass))

typedef struct _MainWindow MainWindow;
typedef struct _MainWindowClass MainWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_MENU_TOOL_ACTION (menu_tool_action_get_type ())
#define MENU_TOOL_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MENU_TOOL_ACTION, MenuToolAction))
#define MENU_TOOL_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MENU_TOOL_ACTION, MenuToolActionClass))
#define IS_MENU_TOOL_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MENU_TOOL_ACTION))
#define IS_MENU_TOOL_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MENU_TOOL_ACTION))
#define MENU_TOOL_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MENU_TOOL_ACTION, MenuToolActionClass))

typedef struct _MenuToolAction MenuToolAction;
typedef struct _MenuToolActionClass MenuToolActionClass;

#define TYPE_DOCUMENT_TAB (document_tab_get_type ())
#define DOCUMENT_TAB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DOCUMENT_TAB, DocumentTab))
#define DOCUMENT_TAB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DOCUMENT_TAB, DocumentTabClass))
#define IS_DOCUMENT_TAB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DOCUMENT_TAB))
#define IS_DOCUMENT_TAB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DOCUMENT_TAB))
#define DOCUMENT_TAB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DOCUMENT_TAB, DocumentTabClass))

typedef struct _DocumentTab DocumentTab;
typedef struct _DocumentTabClass DocumentTabClass;

#define TYPE_DOCUMENT (document_get_type ())
#define DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DOCUMENT, Document))
#define DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DOCUMENT, DocumentClass))
#define IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DOCUMENT))
#define IS_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DOCUMENT))
#define DOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DOCUMENT, DocumentClass))

typedef struct _Document Document;
typedef struct _DocumentClass DocumentClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_DOCUMENT_VIEW (document_view_get_type ())
#define DOCUMENT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DOCUMENT_VIEW, DocumentView))
#define DOCUMENT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DOCUMENT_VIEW, DocumentViewClass))
#define IS_DOCUMENT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DOCUMENT_VIEW))
#define IS_DOCUMENT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DOCUMENT_VIEW))
#define DOCUMENT_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DOCUMENT_VIEW, DocumentViewClass))

typedef struct _DocumentView DocumentView;
typedef struct _DocumentViewClass DocumentViewClass;

#define TYPE_SELECTION_TYPE (selection_type_get_type ())

struct _LatexMenu {
	GtkActionGroup parent_instance;
	LatexMenuPrivate * priv;
};

struct _LatexMenuClass {
	GtkActionGroupClass parent_class;
};

struct _LatexMenuPrivate {
	MainWindow* main_window;
};

typedef enum  {
	SELECTION_TYPE_NO_SELECTION,
	SELECTION_TYPE_ONE_LINE,
	SELECTION_TYPE_MULTIPLE_LINES
} SelectionType;


static gpointer latex_menu_parent_class = NULL;

GType latex_menu_get_type (void) G_GNUC_CONST;
GType main_window_get_type (void) G_GNUC_CONST;
#define LATEX_MENU_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_LATEX_MENU, LatexMenuPrivate))
enum  {
	LATEX_MENU_DUMMY_PROPERTY
};
void latex_menu_on_sectioning_part (LatexMenu* self);
static void _latex_menu_on_sectioning_part_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_sectioning_chapter (LatexMenu* self);
static void _latex_menu_on_sectioning_chapter_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_sectioning_section (LatexMenu* self);
static void _latex_menu_on_sectioning_section_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_sectioning_subsection (LatexMenu* self);
static void _latex_menu_on_sectioning_subsection_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_sectioning_subsubsection (LatexMenu* self);
static void _latex_menu_on_sectioning_subsubsection_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_sectioning_paragraph (LatexMenu* self);
static void _latex_menu_on_sectioning_paragraph_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_sectioning_subparagraph (LatexMenu* self);
static void _latex_menu_on_sectioning_subparagraph_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_ref_label (LatexMenu* self);
static void _latex_menu_on_ref_label_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_ref_ref (LatexMenu* self);
static void _latex_menu_on_ref_ref_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_ref_pageref (LatexMenu* self);
static void _latex_menu_on_ref_pageref_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_ref_index (LatexMenu* self);
static void _latex_menu_on_ref_index_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_ref_footnote (LatexMenu* self);
static void _latex_menu_on_ref_footnote_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_ref_cite (LatexMenu* self);
static void _latex_menu_on_ref_cite_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_env_center (LatexMenu* self);
static void _latex_menu_on_env_center_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_env_left (LatexMenu* self);
static void _latex_menu_on_env_left_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_env_right (LatexMenu* self);
static void _latex_menu_on_env_right_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_env_figure (LatexMenu* self);
static void _latex_menu_on_env_figure_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_env_table (LatexMenu* self);
static void _latex_menu_on_env_table_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_env_quote (LatexMenu* self);
static void _latex_menu_on_env_quote_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_env_quotation (LatexMenu* self);
static void _latex_menu_on_env_quotation_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_env_verse (LatexMenu* self);
static void _latex_menu_on_env_verse_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_env_verbatim (LatexMenu* self);
static void _latex_menu_on_env_verbatim_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_env_minipage (LatexMenu* self);
static void _latex_menu_on_env_minipage_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_env_titlepage (LatexMenu* self);
static void _latex_menu_on_env_titlepage_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_list_env_itemize (LatexMenu* self);
static void _latex_menu_on_list_env_itemize_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_list_env_enumerate (LatexMenu* self);
static void _latex_menu_on_list_env_enumerate_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_list_env_description (LatexMenu* self);
static void _latex_menu_on_list_env_description_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_list_env_list (LatexMenu* self);
static void _latex_menu_on_list_env_list_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_list_env_item (LatexMenu* self);
static void _latex_menu_on_list_env_item_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_size_tiny (LatexMenu* self);
static void _latex_menu_on_size_tiny_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_size_scriptsize (LatexMenu* self);
static void _latex_menu_on_size_scriptsize_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_size_footnotesize (LatexMenu* self);
static void _latex_menu_on_size_footnotesize_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_size_small (LatexMenu* self);
static void _latex_menu_on_size_small_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_size_normalsize (LatexMenu* self);
static void _latex_menu_on_size_normalsize_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_size_large (LatexMenu* self);
static void _latex_menu_on_size_large_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_size_Large (LatexMenu* self);
static void _latex_menu_on_size_Large_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_size_LARGE (LatexMenu* self);
static void _latex_menu_on_size_LARGE_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_size_huge (LatexMenu* self);
static void _latex_menu_on_size_huge_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_size_Huge (LatexMenu* self);
static void _latex_menu_on_size_Huge_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_bold (LatexMenu* self);
static void _latex_menu_on_text_bold_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_italic (LatexMenu* self);
static void _latex_menu_on_text_italic_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_typewriter (LatexMenu* self);
static void _latex_menu_on_text_typewriter_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_slanted (LatexMenu* self);
static void _latex_menu_on_text_slanted_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_small_caps (LatexMenu* self);
static void _latex_menu_on_text_small_caps_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_sans_serif (LatexMenu* self);
static void _latex_menu_on_text_sans_serif_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_emph (LatexMenu* self);
static void _latex_menu_on_text_emph_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_underline (LatexMenu* self);
static void _latex_menu_on_text_underline_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_font_family_roman (LatexMenu* self);
static void _latex_menu_on_text_font_family_roman_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_font_family_sans_serif (LatexMenu* self);
static void _latex_menu_on_text_font_family_sans_serif_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_font_family_monospace (LatexMenu* self);
static void _latex_menu_on_text_font_family_monospace_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_font_series_medium (LatexMenu* self);
static void _latex_menu_on_text_font_series_medium_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_font_series_bold (LatexMenu* self);
static void _latex_menu_on_text_font_series_bold_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_font_shape_upright (LatexMenu* self);
static void _latex_menu_on_text_font_shape_upright_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_font_shape_italic (LatexMenu* self);
static void _latex_menu_on_text_font_shape_italic_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_font_shape_slanted (LatexMenu* self);
static void _latex_menu_on_text_font_shape_slanted_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_text_font_shape_small_caps (LatexMenu* self);
static void _latex_menu_on_text_font_shape_small_caps_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_tabular_tabbing (LatexMenu* self);
static void _latex_menu_on_tabular_tabbing_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_tabular_tabular (LatexMenu* self);
static void _latex_menu_on_tabular_tabular_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_tabular_multicolumn (LatexMenu* self);
static void _latex_menu_on_tabular_multicolumn_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_tabular_hline (LatexMenu* self);
static void _latex_menu_on_tabular_hline_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_tabular_vline (LatexMenu* self);
static void _latex_menu_on_tabular_vline_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_tabular_cline (LatexMenu* self);
static void _latex_menu_on_tabular_cline_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_present_frame (LatexMenu* self);
static void _latex_menu_on_present_frame_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_present_block (LatexMenu* self);
static void _latex_menu_on_present_block_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_present_columns (LatexMenu* self);
static void _latex_menu_on_present_columns_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_spacing_new_line (LatexMenu* self);
static void _latex_menu_on_spacing_new_line_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_spacing_new_page (LatexMenu* self);
static void _latex_menu_on_spacing_new_page_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_spacing_line_break (LatexMenu* self);
static void _latex_menu_on_spacing_line_break_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_spacing_page_break (LatexMenu* self);
static void _latex_menu_on_spacing_page_break_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_spacing_bigskip (LatexMenu* self);
static void _latex_menu_on_spacing_bigskip_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_spacing_medskip (LatexMenu* self);
static void _latex_menu_on_spacing_medskip_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_spacing_hspace (LatexMenu* self);
static void _latex_menu_on_spacing_hspace_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_spacing_vspace (LatexMenu* self);
static void _latex_menu_on_spacing_vspace_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_spacing_noindent (LatexMenu* self);
static void _latex_menu_on_spacing_noindent_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent0 (LatexMenu* self);
static void _latex_menu_on_accent0_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent1 (LatexMenu* self);
static void _latex_menu_on_accent1_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent2 (LatexMenu* self);
static void _latex_menu_on_accent2_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent3 (LatexMenu* self);
static void _latex_menu_on_accent3_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent4 (LatexMenu* self);
static void _latex_menu_on_accent4_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent5 (LatexMenu* self);
static void _latex_menu_on_accent5_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent6 (LatexMenu* self);
static void _latex_menu_on_accent6_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent7 (LatexMenu* self);
static void _latex_menu_on_accent7_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent8 (LatexMenu* self);
static void _latex_menu_on_accent8_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent9 (LatexMenu* self);
static void _latex_menu_on_accent9_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent10 (LatexMenu* self);
static void _latex_menu_on_accent10_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent11 (LatexMenu* self);
static void _latex_menu_on_accent11_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent12 (LatexMenu* self);
static void _latex_menu_on_accent12_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent13 (LatexMenu* self);
static void _latex_menu_on_accent13_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent14 (LatexMenu* self);
static void _latex_menu_on_accent14_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_accent15 (LatexMenu* self);
static void _latex_menu_on_accent15_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_documentclass (LatexMenu* self);
static void _latex_menu_on_documentclass_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_usepackage (LatexMenu* self);
static void _latex_menu_on_usepackage_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_ams_packages (LatexMenu* self);
static void _latex_menu_on_ams_packages_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_author (LatexMenu* self);
static void _latex_menu_on_author_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_title (LatexMenu* self);
static void _latex_menu_on_title_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_begin_document (LatexMenu* self);
static void _latex_menu_on_begin_document_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_maketitle (LatexMenu* self);
static void _latex_menu_on_maketitle_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_tableofcontents (LatexMenu* self);
static void _latex_menu_on_tableofcontents_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_abstract (LatexMenu* self);
static void _latex_menu_on_abstract_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_include_graphics (LatexMenu* self);
static void _latex_menu_on_include_graphics_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_input (LatexMenu* self);
static void _latex_menu_on_input_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_env_normal (LatexMenu* self);
static void _latex_menu_on_math_env_normal_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_env_centered (LatexMenu* self);
static void _latex_menu_on_math_env_centered_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_env_numbered (LatexMenu* self);
static void _latex_menu_on_math_env_numbered_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_env_array (LatexMenu* self);
static void _latex_menu_on_math_env_array_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_env_numbered_array (LatexMenu* self);
static void _latex_menu_on_math_env_numbered_array_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_superscript (LatexMenu* self);
static void _latex_menu_on_math_superscript_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_subscript (LatexMenu* self);
static void _latex_menu_on_math_subscript_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_frac (LatexMenu* self);
static void _latex_menu_on_math_frac_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_square_root (LatexMenu* self);
static void _latex_menu_on_math_square_root_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_nth_root (LatexMenu* self);
static void _latex_menu_on_math_nth_root_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_arccos (LatexMenu* self);
static void _latex_menu_on_math_func_arccos_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_arcsin (LatexMenu* self);
static void _latex_menu_on_math_func_arcsin_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_arctan (LatexMenu* self);
static void _latex_menu_on_math_func_arctan_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_cos (LatexMenu* self);
static void _latex_menu_on_math_func_cos_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_cosh (LatexMenu* self);
static void _latex_menu_on_math_func_cosh_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_cot (LatexMenu* self);
static void _latex_menu_on_math_func_cot_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_coth (LatexMenu* self);
static void _latex_menu_on_math_func_coth_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_csc (LatexMenu* self);
static void _latex_menu_on_math_func_csc_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_deg (LatexMenu* self);
static void _latex_menu_on_math_func_deg_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_det (LatexMenu* self);
static void _latex_menu_on_math_func_det_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_dim (LatexMenu* self);
static void _latex_menu_on_math_func_dim_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_exp (LatexMenu* self);
static void _latex_menu_on_math_func_exp_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_gcd (LatexMenu* self);
static void _latex_menu_on_math_func_gcd_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_hom (LatexMenu* self);
static void _latex_menu_on_math_func_hom_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_inf (LatexMenu* self);
static void _latex_menu_on_math_func_inf_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_ker (LatexMenu* self);
static void _latex_menu_on_math_func_ker_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_lg (LatexMenu* self);
static void _latex_menu_on_math_func_lg_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_lim (LatexMenu* self);
static void _latex_menu_on_math_func_lim_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_liminf (LatexMenu* self);
static void _latex_menu_on_math_func_liminf_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_limsup (LatexMenu* self);
static void _latex_menu_on_math_func_limsup_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_ln (LatexMenu* self);
static void _latex_menu_on_math_func_ln_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_log (LatexMenu* self);
static void _latex_menu_on_math_func_log_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_max (LatexMenu* self);
static void _latex_menu_on_math_func_max_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_min (LatexMenu* self);
static void _latex_menu_on_math_func_min_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_sec (LatexMenu* self);
static void _latex_menu_on_math_func_sec_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_sin (LatexMenu* self);
static void _latex_menu_on_math_func_sin_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_sinh (LatexMenu* self);
static void _latex_menu_on_math_func_sinh_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_sup (LatexMenu* self);
static void _latex_menu_on_math_func_sup_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_tan (LatexMenu* self);
static void _latex_menu_on_math_func_tan_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_func_tanh (LatexMenu* self);
static void _latex_menu_on_math_func_tanh_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_font_style_rm (LatexMenu* self);
static void _latex_menu_on_math_font_style_rm_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_font_style_it (LatexMenu* self);
static void _latex_menu_on_math_font_style_it_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_font_style_bf (LatexMenu* self);
static void _latex_menu_on_math_font_style_bf_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_font_style_sf (LatexMenu* self);
static void _latex_menu_on_math_font_style_sf_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_font_style_tt (LatexMenu* self);
static void _latex_menu_on_math_font_style_tt_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_font_style_cal (LatexMenu* self);
static void _latex_menu_on_math_font_style_cal_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_font_style_bb (LatexMenu* self);
static void _latex_menu_on_math_font_style_bb_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_font_style_frak (LatexMenu* self);
static void _latex_menu_on_math_font_style_frak_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_accent_acute (LatexMenu* self);
static void _latex_menu_on_math_accent_acute_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_accent_grave (LatexMenu* self);
static void _latex_menu_on_math_accent_grave_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_accent_tilde (LatexMenu* self);
static void _latex_menu_on_math_accent_tilde_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_accent_bar (LatexMenu* self);
static void _latex_menu_on_math_accent_bar_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_accent_vec (LatexMenu* self);
static void _latex_menu_on_math_accent_vec_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_accent_hat (LatexMenu* self);
static void _latex_menu_on_math_accent_hat_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_accent_check (LatexMenu* self);
static void _latex_menu_on_math_accent_check_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_accent_breve (LatexMenu* self);
static void _latex_menu_on_math_accent_breve_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_accent_dot (LatexMenu* self);
static void _latex_menu_on_math_accent_dot_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_accent_ddot (LatexMenu* self);
static void _latex_menu_on_math_accent_ddot_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_accent_ring (LatexMenu* self);
static void _latex_menu_on_math_accent_ring_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_space_small (LatexMenu* self);
static void _latex_menu_on_math_space_small_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_space_medium (LatexMenu* self);
static void _latex_menu_on_math_space_medium_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_space_large (LatexMenu* self);
static void _latex_menu_on_math_space_large_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_space_quad (LatexMenu* self);
static void _latex_menu_on_math_space_quad_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_space_qquad (LatexMenu* self);
static void _latex_menu_on_math_space_qquad_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_left_delimiter_1 (LatexMenu* self);
static void _latex_menu_on_math_left_delimiter_1_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_left_delimiter_2 (LatexMenu* self);
static void _latex_menu_on_math_left_delimiter_2_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_left_delimiter_3 (LatexMenu* self);
static void _latex_menu_on_math_left_delimiter_3_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_left_delimiter_4 (LatexMenu* self);
static void _latex_menu_on_math_left_delimiter_4_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_left_delimiter_5 (LatexMenu* self);
static void _latex_menu_on_math_left_delimiter_5_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_left_delimiter_6 (LatexMenu* self);
static void _latex_menu_on_math_left_delimiter_6_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_left_delimiter_7 (LatexMenu* self);
static void _latex_menu_on_math_left_delimiter_7_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_left_delimiter_8 (LatexMenu* self);
static void _latex_menu_on_math_left_delimiter_8_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_left_delimiter_9 (LatexMenu* self);
static void _latex_menu_on_math_left_delimiter_9_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_right_delimiter_1 (LatexMenu* self);
static void _latex_menu_on_math_right_delimiter_1_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_right_delimiter_2 (LatexMenu* self);
static void _latex_menu_on_math_right_delimiter_2_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_right_delimiter_3 (LatexMenu* self);
static void _latex_menu_on_math_right_delimiter_3_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_right_delimiter_4 (LatexMenu* self);
static void _latex_menu_on_math_right_delimiter_4_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_right_delimiter_5 (LatexMenu* self);
static void _latex_menu_on_math_right_delimiter_5_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_right_delimiter_6 (LatexMenu* self);
static void _latex_menu_on_math_right_delimiter_6_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_right_delimiter_7 (LatexMenu* self);
static void _latex_menu_on_math_right_delimiter_7_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_right_delimiter_8 (LatexMenu* self);
static void _latex_menu_on_math_right_delimiter_8_gtk_action_callback (GtkAction* action, gpointer self);
void latex_menu_on_math_right_delimiter_9 (LatexMenu* self);
static void _latex_menu_on_math_right_delimiter_9_gtk_action_callback (GtkAction* action, gpointer self);
LatexMenu* latex_menu_new (MainWindow* main_window);
LatexMenu* latex_menu_construct (GType object_type, MainWindow* main_window);
static GtkAction* latex_menu_get_menu_tool_action (LatexMenu* self, const gchar* name, const gchar* label, const gchar* stock_id);
MenuToolAction* menu_tool_action_new (const gchar* name, const gchar* label, const gchar* tooltip, const gchar* stock_id);
MenuToolAction* menu_tool_action_construct (GType object_type, const gchar* name, const gchar* label, const gchar* tooltip, const gchar* stock_id);
GType menu_tool_action_get_type (void) G_GNUC_CONST;
static void latex_menu_text_buffer_insert (LatexMenu* self, const gchar* text_before, const gchar* text_after, const gchar* text_if_no_selection);
GType document_tab_get_type (void) G_GNUC_CONST;
DocumentTab* main_window_get_active_tab (MainWindow* self);
GType document_get_type (void) G_GNUC_CONST;
Document* main_window_get_active_document (MainWindow* self);
gchar* document_get_current_indentation (Document* self, GtkTextIter* iter);
void document_insert (Document* self, GtkTextIter* iter, const gchar* text, gint len);
static gchar* latex_menu_get_indentation (LatexMenu* self);
GType document_view_get_type (void) G_GNUC_CONST;
DocumentView* main_window_get_active_view (MainWindow* self);
gchar* document_view_get_indentation_style (DocumentView* self);
static void latex_menu_insert_character_style (LatexMenu* self, const gchar* style);
GType selection_type_get_type (void) G_GNUC_CONST;
SelectionType document_get_selection_type (Document* self);
static void latex_menu_finalize (GObject* obj);

static const GtkActionEntry LATEX_MENU_latex_action_entries[206] = {{"Latex", NULL, "_LaTeX"}, {"Sectioning", "sectioning-section", "_Sectioning"}, {"SectioningPart", "sectioning-part", "\\_part", NULL, "Part", (GCallback) _latex_menu_on_sectioning_part_gtk_action_callback}, {"SectioningChapter", "sectioning-chapter", "\\_chapter", NULL, "Chapter", (GCallback) _latex_menu_on_sectioning_chapter_gtk_action_callback}, {"SectioningSection", "sectioning-section", "\\_section", NULL, "Section", (GCallback) _latex_menu_on_sectioning_section_gtk_action_callback}, {"SectioningSubsection", "sectioning-subsection", "\\s_ubsection", NULL, "Sub-section", (GCallback) _latex_menu_on_sectioning_subsection_gtk_action_callback}, {"SectioningSubsubsection", "sectioning-subsubsection", "\\su_bsubsection", NULL, "Sub-sub-section", (GCallback) _latex_menu_on_sectioning_subsubsection_gtk_action_callback}, {"SectioningParagraph", "sectioning-paragraph", "\\p_aragraph", NULL, "Paragraph", (GCallback) _latex_menu_on_sectioning_paragraph_gtk_action_callback}, {"SectioningSubparagraph", "sectioning-paragraph", "\\subpa_ragraph", NULL, "Sub-paragraph", (GCallback) _latex_menu_on_sectioning_subparagraph_gtk_action_callback}, {"References", "references", "_References"}, {"ReferencesLabel", NULL, "\\_label", NULL, "Label", (GCallback) _latex_menu_on_ref_label_gtk_action_callback}, {"ReferencesRef", NULL, "\\_ref", NULL, "Reference to a label", (GCallback) _latex_menu_on_ref_ref_gtk_action_callback}, {"ReferencesPageref", NULL, "\\_pageref", NULL, "Page reference to a label", (GCallback) _latex_menu_on_ref_pageref_gtk_action_callback}, {"ReferencesIndex", NULL, "\\_index", NULL, "Add a word to the index", (GCallback) _latex_menu_on_ref_index_gtk_action_callback}, {"ReferencesFootnote", NULL, "\\_footnote", NULL, "Footnote", (GCallback) _latex_menu_on_ref_footnote_gtk_action_callback}, {"ReferencesCite", NULL, "\\_cite", NULL, "Reference to a bibliography item", (GCallback) _latex_menu_on_ref_cite_gtk_action_callback}, {"Environments", GTK_STOCK_JUSTIFY_CENTER, "_Environments"}, {"EnvCenter", GTK_STOCK_JUSTIFY_CENTER, "\\begin{_center}", NULL, "Center - \\begin{center}", (GCallback) _latex_menu_on_env_center_gtk_action_callback}, {"EnvLeft", GTK_STOCK_JUSTIFY_LEFT, "\\begin{flush_left}", NULL, "Align Left - \\begin{flushleft}", (GCallback) _latex_menu_on_env_left_gtk_action_callback}, {"EnvRight", GTK_STOCK_JUSTIFY_RIGHT, "\\begin{flush_right}", NULL, "Align Right - \\begin{flushright}", (GCallback) _latex_menu_on_env_right_gtk_action_callback}, {"EnvFigure", "image", "\\begin{_figure}", NULL, "Figure - \\begin{figure}", (GCallback) _latex_menu_on_env_figure_gtk_action_callback}, {"EnvTable", "table", "\\begin{_table}", NULL, "Table - \\begin{table}", (GCallback) _latex_menu_on_env_table_gtk_action_callback}, {"EnvQuote", NULL, "\\begin{_quote}", NULL, "Quote - \\begin{quote}", (GCallback) _latex_menu_on_env_quote_gtk_action_callback}, {"EnvQuotation", NULL, "\\begin{qu_otation}", NULL, "Quotation - \\begin{quotation}", (GCallback) _latex_menu_on_env_quotation_gtk_action_callback}, {"EnvVerse", NULL, "\\begin{_verse}", NULL, "Verse - \\begin{verse}", (GCallback) _latex_menu_on_env_verse_gtk_action_callback}, {"EnvVerbatim", NULL, "\\begin{ver_batim}", NULL, "Verbatim - \\begin{verbatim}", (GCallback) _latex_menu_on_env_verbatim_gtk_action_callback}, {"EnvMinipage", NULL, "\\begin{_minipage}", NULL, "Minipage - \\begin{minipage}", (GCallback) _latex_menu_on_env_minipage_gtk_action_callback}, {"EnvTitlepage", NULL, "\\begin{titlepage}", NULL, "Title page - \\begin{titlepage}", (GCallback) _latex_menu_on_env_titlepage_gtk_action_callback}, {"ListEnvironments", "list-enumerate", "_List Environments"}, {"ListEnvItemize", "list-itemize", "\\begin{_itemize}", NULL, "Bulleted List - \\begin{itemize}", (GCallback) _latex_menu_on_list_env_itemize_gtk_action_callback}, {"ListEnvEnumerate", "list-enumerate", "\\begin{_enumerate}", NULL, "Enumeration - \\begin{enumerate}", (GCallback) _latex_menu_on_list_env_enumerate_gtk_action_callback}, {"ListEnvDescription", "list-description", "\\begin{_description}", NULL, "Description - \\begin{description}", (GCallback) _latex_menu_on_list_env_description_gtk_action_callback}, {"ListEnvList", NULL, "\\begin{_list}", NULL, "Custom list - \\begin{list}", (GCallback) _latex_menu_on_list_env_list_gtk_action_callback}, {"ListEnvItem", "list-item", "\\i_tem", "<Alt><Shift>H", "List item - \\item", (GCallback) _latex_menu_on_list_env_item_gtk_action_callback}, {"CharacterSize", "character-size", "_Characters Sizes"}, {"CharacterSizeTiny", NULL, "_tiny", NULL, "tiny", (GCallback) _latex_menu_on_size_tiny_gtk_action_callback}, {"CharacterSizeScriptsize", NULL, "_scriptsize", NULL, "scriptsize", (GCallback) _latex_menu_on_size_scriptsize_gtk_action_callback}, {"CharacterSizeFootnotesize", NULL, "_footnotesize", NULL, "footnotesize", (GCallback) _latex_menu_on_size_footnotesize_gtk_action_callback}, {"CharacterSizeSmall", NULL, "s_mall", NULL, "small", (GCallback) _latex_menu_on_size_small_gtk_action_callback}, {"CharacterSizeNormalsize", NULL, "_normalsize", NULL, "normalsize", (GCallback) _latex_menu_on_size_normalsize_gtk_action_callback}, {"CharacterSizelarge", NULL, "_large", NULL, "large", (GCallback) _latex_menu_on_size_large_gtk_action_callback}, {"CharacterSizeLarge", NULL, "L_arge", NULL, "Large", (GCallback) _latex_menu_on_size_Large_gtk_action_callback}, {"CharacterSizeLARGE", NULL, "LA_RGE", NULL, "LARGE", (GCallback) _latex_menu_on_size_LARGE_gtk_action_callback}, {"CharacterSizehuge", NULL, "_huge", NULL, "huge", (GCallback) _latex_menu_on_size_huge_gtk_action_callback}, {"CharacterSizeHuge", NULL, "H_uge", NULL, "Huge", (GCallback) _latex_menu_on_size_Huge_gtk_action_callback}, {"FontStyles", "bold", "_Font Styles"}, {"Bold", "bold", "\\text_bf", "<Alt><Shift>B", "Bold - \\textbf", (GCallback) _latex_menu_on_text_bold_gtk_action_callback}, {"Italic", "italic", "\\text_it", "<Alt><Shift>I", "Italic - \\textit", (GCallback) _latex_menu_on_text_italic_gtk_action_callback}, {"Typewriter", "typewriter", "\\text_tt", "<Alt><Shift>T", "Typewriter - \\texttt", (GCallback) _latex_menu_on_text_typewriter_gtk_action_callback}, {"Slanted", "slanted", "\\text_sl", "<Alt><Shift>S", "Slanted - \\textsl", (GCallback) _latex_menu_on_text_slanted_gtk_action_callback}, {"SmallCaps", "small_caps", "\\texts_c", "<Alt><Shift>C", "Small Capitals - \\textsc", (GCallback) _latex_menu_on_text_small_caps_gtk_action_callback}, {"SansSerif", "sans_serif", "\\texts_f", NULL, "Sans Serif - \\textsf", (GCallback) _latex_menu_on_text_sans_serif_gtk_action_callback}, {"Emph", NULL, "\\_emph", "<Control>E", "Emphasized - \\emph", (GCallback) _latex_menu_on_text_emph_gtk_action_callback}, {"Underline", "underline", "\\_underline", NULL, "Underline - \\underline", (GCallback) _latex_menu_on_text_underline_gtk_action_callback}, {"FontFamily", NULL, "_Font Family"}, {"FontFamilyRoman", "roman", "\\_rmfamily", NULL, "Roman - \\rmfamily", (GCallback) _latex_menu_on_text_font_family_roman_gtk_action_callback}, {"FontFamilySansSerif", "sans_serif", "\\_sffamily", NULL, "Sans Serif - \\sffamily", (GCallback) _latex_menu_on_text_font_family_sans_serif_gtk_action_callback}, {"FontFamilyMonospace", "typewriter", "\\_ttfamily", NULL, "Monospace - \\ttfamily", (GCallback) _latex_menu_on_text_font_family_monospace_gtk_action_callback}, {"FontSeries", NULL, "F_ont Series"}, {"FontSeriesMedium", "roman", "\\_mdseries", NULL, "Medium - \\mdseries", (GCallback) _latex_menu_on_text_font_series_medium_gtk_action_callback}, {"FontSeriesBold", "bold", "\\_bfseries", NULL, "Bold - \\bfseries", (GCallback) _latex_menu_on_text_font_series_bold_gtk_action_callback}, {"FontShape", NULL, "Fo_nt Shape"}, {"FontShapeUpright", "roman", "\\_upshape", NULL, "Upright - \\upshape", (GCallback) _latex_menu_on_text_font_shape_upright_gtk_action_callback}, {"FontShapeItalic", "italic", "\\_itshape", NULL, "Italic - \\itshape", (GCallback) _latex_menu_on_text_font_shape_italic_gtk_action_callback}, {"FontShapeSlanted", "slanted", "\\_slshape", NULL, "Slanted - \\slshape", (GCallback) _latex_menu_on_text_font_shape_slanted_gtk_action_callback}, {"FontShapeSmallCaps", "small_caps", "\\s_cshape", NULL, "Small Capitals - \\scshape", (GCallback) _latex_menu_on_text_font_shape_small_caps_gtk_action_callback}, {"Tabular", "table", "_Tabular"}, {"TabularTabbing", NULL, "\\begin{ta_bbing}", NULL, "Tabbing - \\begin{tabbing}", (GCallback) _latex_menu_on_tabular_tabbing_gtk_action_callback}, {"TabularTabular", NULL, "\\begin{_tabular}", NULL, "Tabular - \\begin{tabular}", (GCallback) _latex_menu_on_tabular_tabular_gtk_action_callback}, {"TabularMulticolumn", NULL, "\\_multicolumn", NULL, "Multicolumn - \\multicolumn", (GCallback) _latex_menu_on_tabular_multicolumn_gtk_action_callback}, {"TabularHline", NULL, "\\_hline", NULL, "Horizontal line - \\hline", (GCallback) _latex_menu_on_tabular_hline_gtk_action_callback}, {"TabularVline", NULL, "\\_vline", NULL, "Vertical line - \\vline", (GCallback) _latex_menu_on_tabular_vline_gtk_action_callback}, {"TabularCline", NULL, "\\_cline", NULL, "Horizontal line (columns specified) - \\cline", (GCallback) _latex_menu_on_tabular_cline_gtk_action_callback}, {"Presentation", "presentation", "_Presentation"}, {"PresentationFrame", NULL, "\\begin{frame}", NULL, "Frame - \\begin{frame}", (GCallback) _latex_menu_on_present_frame_gtk_action_callback}, {"PresentationBlock", NULL, "\\begin{block}", NULL, "Block - \\begin{block}", (GCallback) _latex_menu_on_present_block_gtk_action_callback}, {"PresentationColumns", NULL, "\\begin{columns}", NULL, "Two columns - \\begin{columns}", (GCallback) _latex_menu_on_present_columns_gtk_action_callback}, {"Spacing", NULL, "_Spacing"}, {"SpacingNewLine", NULL, "New _Line", NULL, "New Line - \\\\", (GCallback) _latex_menu_on_spacing_new_line_gtk_action_callback}, {"SpacingNewPage", NULL, "\\new_page", NULL, "New page - \\newpage", (GCallback) _latex_menu_on_spacing_new_page_gtk_action_callback}, {"SpacingLineBreak", NULL, "\\l_inebreak", NULL, "Line break - \\linebreak", (GCallback) _latex_menu_on_spacing_line_break_gtk_action_callback}, {"SpacingPageBreak", NULL, "\\p_agebreak", NULL, "Page break - \\pagebreak", (GCallback) _latex_menu_on_spacing_page_break_gtk_action_callback}, {"SpacingBigSkip", NULL, "\\_bigskip", NULL, "Big skip - \\bigskip", (GCallback) _latex_menu_on_spacing_bigskip_gtk_action_callback}, {"SpacingMedSkip", NULL, "\\_medskip", NULL, "Medium skip - \\medskip", (GCallback) _latex_menu_on_spacing_medskip_gtk_action_callback}, {"SpacingHSpace", NULL, "\\_hspace", NULL, "Horizontal space - \\hspace", (GCallback) _latex_menu_on_spacing_hspace_gtk_action_callback}, {"SpacingVSpace", NULL, "\\_vspace", NULL, "Vertical space - \\vspace", (GCallback) _latex_menu_on_spacing_vspace_gtk_action_callback}, {"SpacingNoIndent", NULL, "\\_noindent", NULL, "No paragraph indentation - \\noindent", (GCallback) _latex_menu_on_spacing_noindent_gtk_action_callback}, {"Accents", NULL, "International _Accents"}, {"Accent0", "accent0", "\\'", NULL, "Acute accent - \\'", (GCallback) _latex_menu_on_accent0_gtk_action_callback}, {"Accent1", "accent1", "\\`", NULL, "Grave accent - \\`", (GCallback) _latex_menu_on_accent1_gtk_action_callback}, {"Accent2", "accent2", "\\^", NULL, "Circumflex accent - \\^", (GCallback) _latex_menu_on_accent2_gtk_action_callback}, {"Accent3", "accent3", "\\\"", NULL, "Trema - \\\"", (GCallback) _latex_menu_on_accent3_gtk_action_callback}, {"Accent4", "accent4", "\\~", NULL, "Tilde - \\~", (GCallback) _latex_menu_on_accent4_gtk_action_callback}, {"Accent5", "accent5", "\\=", NULL, "Macron - \\=", (GCallback) _latex_menu_on_accent5_gtk_action_callback}, {"Accent6", "accent6", "\\.", NULL, "Dot above - \\.", (GCallback) _latex_menu_on_accent6_gtk_action_callback}, {"Accent7", "accent7", "\\v", NULL, "Caron - \\v", (GCallback) _latex_menu_on_accent7_gtk_action_callback}, {"Accent8", "accent8", "\\u", NULL, "Breve - \\u", (GCallback) _latex_menu_on_accent8_gtk_action_callback}, {"Accent9", "accent9", "\\H", NULL, "Double acute accent - \\H", (GCallback) _latex_menu_on_accent9_gtk_action_callback}, {"Accent10", "accent10", "\\c", NULL, "Cedilla - \\c", (GCallback) _latex_menu_on_accent10_gtk_action_callback}, {"Accent11", "accent11", "\\k", NULL, "Ogonek - \\k", (GCallback) _latex_menu_on_accent11_gtk_action_callback}, {"Accent12", "accent12", "\\d", NULL, "Dot below - \\d", (GCallback) _latex_menu_on_accent12_gtk_action_callback}, {"Accent13", "accent13", "\\b", NULL, "Macron below - \\b", (GCallback) _latex_menu_on_accent13_gtk_action_callback}, {"Accent14", "accent14", "\\r", NULL, "Ring - \\r", (GCallback) _latex_menu_on_accent14_gtk_action_callback}, {"Accent15", "accent15", "\\t", NULL, "Tie - \\t", (GCallback) _latex_menu_on_accent15_gtk_action_callback}, {"LatexMisc", NULL, "_Misc"}, {"LatexDocumentClass", NULL, "\\_documentclass", NULL, "Document class - \\documentclass", (GCallback) _latex_menu_on_documentclass_gtk_action_callback}, {"LatexUsepackage", NULL, "\\_usepackage", NULL, "Use package - \\usepackage", (GCallback) _latex_menu_on_usepackage_gtk_action_callback}, {"LatexAMS", NULL, "_AMS packages", NULL, "AMS packages", (GCallback) _latex_menu_on_ams_packages_gtk_action_callback}, {"LatexAuthor", NULL, "\\au_thor", NULL, "Author - \\author", (GCallback) _latex_menu_on_author_gtk_action_callback}, {"LatexTitle", NULL, "\\t_itle", NULL, "Title - \\title", (GCallback) _latex_menu_on_title_gtk_action_callback}, {"LatexBeginDocument", NULL, "\\begin{d_ocument}", NULL, "Content of the document - \\begin{document}", (GCallback) _latex_menu_on_begin_document_gtk_action_callback}, {"LatexMakeTitle", NULL, "\\_maketitle", NULL, "Make title - \\maketitle", (GCallback) _latex_menu_on_maketitle_gtk_action_callback}, {"LatexTableOfContents", NULL, "\\tableof_contents", NULL, "Table of contents - \\tableofcontents", (GCallback) _latex_menu_on_tableofcontents_gtk_action_callback}, {"LatexAbstract", NULL, "\\begin{abst_ract}", NULL, "Abstract - \\begin{abstract}", (GCallback) _latex_menu_on_abstract_gtk_action_callback}, {"LatexIncludeGraphics", NULL, "\\include_graphics", NULL, "Include an image (graphicx package) - \\includegraphics", (GCallback) _latex_menu_on_include_graphics_gtk_action_callback}, {"LatexInput", NULL, "\\_input", NULL, "Include a file - \\input", (GCallback) _latex_menu_on_input_gtk_action_callback}, {"Math", NULL, "_Math"}, {"MathEnvironments", NULL, "_Math Environments"}, {"MathEnvNormal", "math", "_Mathematical Environment - $...$", "<Alt><Shift>M", "Mathematical Environment - $...$", (GCallback) _latex_menu_on_math_env_normal_gtk_action_callback}, {"MathEnvCentered", "math-centered", "_Centered Formula - \\[...\\]", "<Alt><Shift>E", "Centered Formula - \\[...\\]", (GCallback) _latex_menu_on_math_env_centered_gtk_action_callback}, {"MathEnvNumbered", "math-numbered", "_Numbered Equation - \\begin{equation}", NULL, "Numbered Equation - \\begin{equation}", (GCallback) _latex_menu_on_math_env_numbered_gtk_action_callback}, {"MathEnvArray", "math-array", "_Array of Equations - \\begin{align*}", NULL, "Array of Equations - \\begin{align*}", (GCallback) _latex_menu_on_math_env_array_gtk_action_callback}, {"MathEnvNumberedArray", "math-numbered-array", "Numbered Array of _Equations - \\begin{align}", NULL, "Numbered Array of Equations - \\begin{align}", (GCallback) _latex_menu_on_math_env_numbered_array_gtk_action_callback}, {"MathSuperscript", "math-superscript", "_Superscript - ^{}", NULL, "Superscript - ^{}", (GCallback) _latex_menu_on_math_superscript_gtk_action_callback}, {"MathSubscript", "math-subscript", "Su_bscript - __{}", NULL, "Subscript - _{}", (GCallback) _latex_menu_on_math_subscript_gtk_action_callback}, {"MathFrac", "math-frac", "_Fraction - \\frac{}{}", "<Alt><Shift>F", "Fraction - \\frac{}{}", (GCallback) _latex_menu_on_math_frac_gtk_action_callback}, {"MathSquareRoot", "math-square-root", "Square _Root - \\sqrt{}", NULL, "Square Root - \\sqrt{}", (GCallback) _latex_menu_on_math_square_root_gtk_action_callback}, {"MathNthRoot", "math-nth-root", "_N-th Root - \\sqrt[]{}", NULL, "N-th Root - \\sqrt[]{}", (GCallback) _latex_menu_on_math_nth_root_gtk_action_callback}, {"MathFunctions", NULL, "Math _Functions"}, {"MathFuncArccos", NULL, "\\arccos", NULL, NULL, (GCallback) _latex_menu_on_math_func_arccos_gtk_action_callback}, {"MathFuncArcsin", NULL, "\\arcsin", NULL, NULL, (GCallback) _latex_menu_on_math_func_arcsin_gtk_action_callback}, {"MathFuncArctan", NULL, "\\arctan", NULL, NULL, (GCallback) _latex_menu_on_math_func_arctan_gtk_action_callback}, {"MathFuncCos", NULL, "\\cos", NULL, NULL, (GCallback) _latex_menu_on_math_func_cos_gtk_action_callback}, {"MathFuncCosh", NULL, "\\cosh", NULL, NULL, (GCallback) _latex_menu_on_math_func_cosh_gtk_action_callback}, {"MathFuncCot", NULL, "\\cot", NULL, NULL, (GCallback) _latex_menu_on_math_func_cot_gtk_action_callback}, {"MathFuncCoth", NULL, "\\coth", NULL, NULL, (GCallback) _latex_menu_on_math_func_coth_gtk_action_callback}, {"MathFuncCsc", NULL, "\\csc", NULL, NULL, (GCallback) _latex_menu_on_math_func_csc_gtk_action_callback}, {"MathFuncDeg", NULL, "\\deg", NULL, NULL, (GCallback) _latex_menu_on_math_func_deg_gtk_action_callback}, {"MathFuncDet", NULL, "\\det", NULL, NULL, (GCallback) _latex_menu_on_math_func_det_gtk_action_callback}, {"MathFuncDim", NULL, "\\dim", NULL, NULL, (GCallback) _latex_menu_on_math_func_dim_gtk_action_callback}, {"MathFuncExp", NULL, "\\exp", NULL, NULL, (GCallback) _latex_menu_on_math_func_exp_gtk_action_callback}, {"MathFuncGcd", NULL, "\\gcd", NULL, NULL, (GCallback) _latex_menu_on_math_func_gcd_gtk_action_callback}, {"MathFuncHom", NULL, "\\hom", NULL, NULL, (GCallback) _latex_menu_on_math_func_hom_gtk_action_callback}, {"MathFuncInf", NULL, "\\inf", NULL, NULL, (GCallback) _latex_menu_on_math_func_inf_gtk_action_callback}, {"MathFuncKer", NULL, "\\ker", NULL, NULL, (GCallback) _latex_menu_on_math_func_ker_gtk_action_callback}, {"MathFuncLg", NULL, "\\lg", NULL, NULL, (GCallback) _latex_menu_on_math_func_lg_gtk_action_callback}, {"MathFuncLim", NULL, "\\lim", NULL, NULL, (GCallback) _latex_menu_on_math_func_lim_gtk_action_callback}, {"MathFuncLiminf", NULL, "\\liminf", NULL, NULL, (GCallback) _latex_menu_on_math_func_liminf_gtk_action_callback}, {"MathFuncLimsup", NULL, "\\limsup", NULL, NULL, (GCallback) _latex_menu_on_math_func_limsup_gtk_action_callback}, {"MathFuncLn", NULL, "\\ln", NULL, NULL, (GCallback) _latex_menu_on_math_func_ln_gtk_action_callback}, {"MathFuncLog", NULL, "\\log", NULL, NULL, (GCallback) _latex_menu_on_math_func_log_gtk_action_callback}, {"MathFuncMax", NULL, "\\max", NULL, NULL, (GCallback) _latex_menu_on_math_func_max_gtk_action_callback}, {"MathFuncMin", NULL, "\\min", NULL, NULL, (GCallback) _latex_menu_on_math_func_min_gtk_action_callback}, {"MathFuncSec", NULL, "\\sec", NULL, NULL, (GCallback) _latex_menu_on_math_func_sec_gtk_action_callback}, {"MathFuncSin", NULL, "\\sin", NULL, NULL, (GCallback) _latex_menu_on_math_func_sin_gtk_action_callback}, {"MathFuncSinh", NULL, "\\sinh", NULL, NULL, (GCallback) _latex_menu_on_math_func_sinh_gtk_action_callback}, {"MathFuncSup", NULL, "\\sup", NULL, NULL, (GCallback) _latex_menu_on_math_func_sup_gtk_action_callback}, {"MathFuncTan", NULL, "\\tan", NULL, NULL, (GCallback) _latex_menu_on_math_func_tan_gtk_action_callback}, {"MathFuncTanh", NULL, "\\tanh", NULL, NULL, (GCallback) _latex_menu_on_math_func_tanh_gtk_action_callback}, {"MathFontStyles", NULL, "Math Font _Styles"}, {"MathFSrm", "roman", "\\math_rm", NULL, "Roman - \\mathrm", (GCallback) _latex_menu_on_math_font_style_rm_gtk_action_callback}, {"MathFSit", "italic", "\\math_it", NULL, "Italic - \\mathit", (GCallback) _latex_menu_on_math_font_style_it_gtk_action_callback}, {"MathFSbf", "bold", "\\math_bf", NULL, "Bold - \\mathbf", (GCallback) _latex_menu_on_math_font_style_bf_gtk_action_callback}, {"MathFSsf", "sans_serif", "\\math_sf", NULL, "Sans Serif - \\mathsf", (GCallback) _latex_menu_on_math_font_style_sf_gtk_action_callback}, {"MathFStt", "typewriter", "\\math_tt", NULL, "Typewriter - \\mathtt", (GCallback) _latex_menu_on_math_font_style_tt_gtk_action_callback}, {"MathFScal", "mathcal", "\\math_cal", NULL, "Calligraphic - \\mathcal", (GCallback) _latex_menu_on_math_font_style_cal_gtk_action_callback}, {"MathFSbb", "blackboard", "\\_mathbb", NULL, "Blackboard (uppercase only)  - \\mathbb (amsfonts package)", (GCallback) _latex_menu_on_math_font_style_bb_gtk_action_callback}, {"MathFSfrak", "mathfrak", "\\math_frak", NULL, "Euler Fraktur - \\mathfrak (amsfonts package)", (GCallback) _latex_menu_on_math_font_style_frak_gtk_action_callback}, {"MathAccents", NULL, "Math _Accents"}, {"MathAccentAcute", "mathaccent0", "\\_acute", NULL, NULL, (GCallback) _latex_menu_on_math_accent_acute_gtk_action_callback}, {"MathAccentGrave", "mathaccent1", "\\_grave", NULL, NULL, (GCallback) _latex_menu_on_math_accent_grave_gtk_action_callback}, {"MathAccentTilde", "mathaccent2", "\\_tilde", NULL, NULL, (GCallback) _latex_menu_on_math_accent_tilde_gtk_action_callback}, {"MathAccentBar", "mathaccent3", "\\_bar", NULL, NULL, (GCallback) _latex_menu_on_math_accent_bar_gtk_action_callback}, {"MathAccentVec", "mathaccent4", "\\_vec", NULL, NULL, (GCallback) _latex_menu_on_math_accent_vec_gtk_action_callback}, {"MathAccentHat", "mathaccent5", "\\_hat", NULL, NULL, (GCallback) _latex_menu_on_math_accent_hat_gtk_action_callback}, {"MathAccentCheck", "mathaccent6", "\\_check", NULL, NULL, (GCallback) _latex_menu_on_math_accent_check_gtk_action_callback}, {"MathAccentBreve", "mathaccent7", "\\b_reve", NULL, NULL, (GCallback) _latex_menu_on_math_accent_breve_gtk_action_callback}, {"MathAccentDot", "mathaccent8", "\\_dot", NULL, NULL, (GCallback) _latex_menu_on_math_accent_dot_gtk_action_callback}, {"MathAccentDdot", "mathaccent9", "\\dd_ot", NULL, NULL, (GCallback) _latex_menu_on_math_accent_ddot_gtk_action_callback}, {"MathAccentRing", "mathaccent10", "\\_mathring", NULL, NULL, (GCallback) _latex_menu_on_math_accent_ring_gtk_action_callback}, {"MathSpaces", NULL, "Math _Spaces"}, {"MathSpaceSmall", NULL, "_Small", NULL, "Small - \\,", (GCallback) _latex_menu_on_math_space_small_gtk_action_callback}, {"MathSpaceMedium", NULL, "_Medium", NULL, "Medium - \\:", (GCallback) _latex_menu_on_math_space_medium_gtk_action_callback}, {"MathSpaceLarge", NULL, "_Large", NULL, "Large - \\;", (GCallback) _latex_menu_on_math_space_large_gtk_action_callback}, {"MathSpaceQuad", NULL, "\\_quad", NULL, NULL, (GCallback) _latex_menu_on_math_space_quad_gtk_action_callback}, {"MathSpaceQquad", NULL, "\\qqu_ad", NULL, NULL, (GCallback) _latex_menu_on_math_space_qquad_gtk_action_callback}, {"MathLeftDelimiters", "delimiters-left", "_Left Delimiters"}, {"MathLeftDelimiter1", NULL, "left (", NULL, NULL, (GCallback) _latex_menu_on_math_left_delimiter_1_gtk_action_callback}, {"MathLeftDelimiter2", NULL, "left [", NULL, NULL, (GCallback) _latex_menu_on_math_left_delimiter_2_gtk_action_callback}, {"MathLeftDelimiter3", NULL, "left { ", NULL, NULL, (GCallback) _latex_menu_on_math_left_delimiter_3_gtk_action_callback}, {"MathLeftDelimiter4", NULL, "left <", NULL, NULL, (GCallback) _latex_menu_on_math_left_delimiter_4_gtk_action_callback}, {"MathLeftDelimiter5", NULL, "left )", NULL, NULL, (GCallback) _latex_menu_on_math_left_delimiter_5_gtk_action_callback}, {"MathLeftDelimiter6", NULL, "left ]", NULL, NULL, (GCallback) _latex_menu_on_math_left_delimiter_6_gtk_action_callback}, {"MathLeftDelimiter7", NULL, "left  }", NULL, NULL, (GCallback) _latex_menu_on_math_left_delimiter_7_gtk_action_callback}, {"MathLeftDelimiter8", NULL, "left >", NULL, NULL, (GCallback) _latex_menu_on_math_left_delimiter_8_gtk_action_callback}, {"MathLeftDelimiter9", NULL, "left .", NULL, NULL, (GCallback) _latex_menu_on_math_left_delimiter_9_gtk_action_callback}, {"MathRightDelimiters", "delimiters-right", "Right _Delimiters"}, {"MathRightDelimiter1", NULL, "right )", NULL, NULL, (GCallback) _latex_menu_on_math_right_delimiter_1_gtk_action_callback}, {"MathRightDelimiter2", NULL, "right ]", NULL, NULL, (GCallback) _latex_menu_on_math_right_delimiter_2_gtk_action_callback}, {"MathRightDelimiter3", NULL, "right  }", NULL, NULL, (GCallback) _latex_menu_on_math_right_delimiter_3_gtk_action_callback}, {"MathRightDelimiter4", NULL, "right >", NULL, NULL, (GCallback) _latex_menu_on_math_right_delimiter_4_gtk_action_callback}, {"MathRightDelimiter5", NULL, "right (", NULL, NULL, (GCallback) _latex_menu_on_math_right_delimiter_5_gtk_action_callback}, {"MathRightDelimiter6", NULL, "right [", NULL, NULL, (GCallback) _latex_menu_on_math_right_delimiter_6_gtk_action_callback}, {"MathRightDelimiter7", NULL, "right { ", NULL, NULL, (GCallback) _latex_menu_on_math_right_delimiter_7_gtk_action_callback}, {"MathRightDelimiter8", NULL, "right <", NULL, NULL, (GCallback) _latex_menu_on_math_right_delimiter_8_gtk_action_callback}, {"MathRightDelimiter9", NULL, "right .", NULL, NULL, (GCallback) _latex_menu_on_math_right_delimiter_9_gtk_action_callback}};

static void _latex_menu_on_sectioning_part_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_sectioning_part (self);
}


static void _latex_menu_on_sectioning_chapter_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_sectioning_chapter (self);
}


static void _latex_menu_on_sectioning_section_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_sectioning_section (self);
}


static void _latex_menu_on_sectioning_subsection_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_sectioning_subsection (self);
}


static void _latex_menu_on_sectioning_subsubsection_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_sectioning_subsubsection (self);
}


static void _latex_menu_on_sectioning_paragraph_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_sectioning_paragraph (self);
}


static void _latex_menu_on_sectioning_subparagraph_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_sectioning_subparagraph (self);
}


static void _latex_menu_on_ref_label_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_ref_label (self);
}


static void _latex_menu_on_ref_ref_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_ref_ref (self);
}


static void _latex_menu_on_ref_pageref_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_ref_pageref (self);
}


static void _latex_menu_on_ref_index_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_ref_index (self);
}


static void _latex_menu_on_ref_footnote_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_ref_footnote (self);
}


static void _latex_menu_on_ref_cite_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_ref_cite (self);
}


static void _latex_menu_on_env_center_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_env_center (self);
}


static void _latex_menu_on_env_left_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_env_left (self);
}


static void _latex_menu_on_env_right_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_env_right (self);
}


static void _latex_menu_on_env_figure_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_env_figure (self);
}


static void _latex_menu_on_env_table_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_env_table (self);
}


static void _latex_menu_on_env_quote_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_env_quote (self);
}


static void _latex_menu_on_env_quotation_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_env_quotation (self);
}


static void _latex_menu_on_env_verse_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_env_verse (self);
}


static void _latex_menu_on_env_verbatim_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_env_verbatim (self);
}


static void _latex_menu_on_env_minipage_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_env_minipage (self);
}


static void _latex_menu_on_env_titlepage_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_env_titlepage (self);
}


static void _latex_menu_on_list_env_itemize_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_list_env_itemize (self);
}


static void _latex_menu_on_list_env_enumerate_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_list_env_enumerate (self);
}


static void _latex_menu_on_list_env_description_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_list_env_description (self);
}


static void _latex_menu_on_list_env_list_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_list_env_list (self);
}


static void _latex_menu_on_list_env_item_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_list_env_item (self);
}


static void _latex_menu_on_size_tiny_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_size_tiny (self);
}


static void _latex_menu_on_size_scriptsize_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_size_scriptsize (self);
}


static void _latex_menu_on_size_footnotesize_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_size_footnotesize (self);
}


static void _latex_menu_on_size_small_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_size_small (self);
}


static void _latex_menu_on_size_normalsize_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_size_normalsize (self);
}


static void _latex_menu_on_size_large_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_size_large (self);
}


static void _latex_menu_on_size_Large_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_size_Large (self);
}


static void _latex_menu_on_size_LARGE_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_size_LARGE (self);
}


static void _latex_menu_on_size_huge_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_size_huge (self);
}


static void _latex_menu_on_size_Huge_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_size_Huge (self);
}


static void _latex_menu_on_text_bold_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_bold (self);
}


static void _latex_menu_on_text_italic_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_italic (self);
}


static void _latex_menu_on_text_typewriter_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_typewriter (self);
}


static void _latex_menu_on_text_slanted_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_slanted (self);
}


static void _latex_menu_on_text_small_caps_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_small_caps (self);
}


static void _latex_menu_on_text_sans_serif_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_sans_serif (self);
}


static void _latex_menu_on_text_emph_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_emph (self);
}


static void _latex_menu_on_text_underline_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_underline (self);
}


static void _latex_menu_on_text_font_family_roman_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_font_family_roman (self);
}


static void _latex_menu_on_text_font_family_sans_serif_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_font_family_sans_serif (self);
}


static void _latex_menu_on_text_font_family_monospace_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_font_family_monospace (self);
}


static void _latex_menu_on_text_font_series_medium_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_font_series_medium (self);
}


static void _latex_menu_on_text_font_series_bold_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_font_series_bold (self);
}


static void _latex_menu_on_text_font_shape_upright_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_font_shape_upright (self);
}


static void _latex_menu_on_text_font_shape_italic_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_font_shape_italic (self);
}


static void _latex_menu_on_text_font_shape_slanted_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_font_shape_slanted (self);
}


static void _latex_menu_on_text_font_shape_small_caps_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_text_font_shape_small_caps (self);
}


static void _latex_menu_on_tabular_tabbing_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_tabular_tabbing (self);
}


static void _latex_menu_on_tabular_tabular_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_tabular_tabular (self);
}


static void _latex_menu_on_tabular_multicolumn_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_tabular_multicolumn (self);
}


static void _latex_menu_on_tabular_hline_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_tabular_hline (self);
}


static void _latex_menu_on_tabular_vline_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_tabular_vline (self);
}


static void _latex_menu_on_tabular_cline_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_tabular_cline (self);
}


static void _latex_menu_on_present_frame_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_present_frame (self);
}


static void _latex_menu_on_present_block_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_present_block (self);
}


static void _latex_menu_on_present_columns_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_present_columns (self);
}


static void _latex_menu_on_spacing_new_line_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_spacing_new_line (self);
}


static void _latex_menu_on_spacing_new_page_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_spacing_new_page (self);
}


static void _latex_menu_on_spacing_line_break_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_spacing_line_break (self);
}


static void _latex_menu_on_spacing_page_break_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_spacing_page_break (self);
}


static void _latex_menu_on_spacing_bigskip_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_spacing_bigskip (self);
}


static void _latex_menu_on_spacing_medskip_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_spacing_medskip (self);
}


static void _latex_menu_on_spacing_hspace_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_spacing_hspace (self);
}


static void _latex_menu_on_spacing_vspace_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_spacing_vspace (self);
}


static void _latex_menu_on_spacing_noindent_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_spacing_noindent (self);
}


static void _latex_menu_on_accent0_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent0 (self);
}


static void _latex_menu_on_accent1_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent1 (self);
}


static void _latex_menu_on_accent2_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent2 (self);
}


static void _latex_menu_on_accent3_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent3 (self);
}


static void _latex_menu_on_accent4_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent4 (self);
}


static void _latex_menu_on_accent5_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent5 (self);
}


static void _latex_menu_on_accent6_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent6 (self);
}


static void _latex_menu_on_accent7_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent7 (self);
}


static void _latex_menu_on_accent8_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent8 (self);
}


static void _latex_menu_on_accent9_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent9 (self);
}


static void _latex_menu_on_accent10_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent10 (self);
}


static void _latex_menu_on_accent11_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent11 (self);
}


static void _latex_menu_on_accent12_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent12 (self);
}


static void _latex_menu_on_accent13_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent13 (self);
}


static void _latex_menu_on_accent14_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent14 (self);
}


static void _latex_menu_on_accent15_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_accent15 (self);
}


static void _latex_menu_on_documentclass_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_documentclass (self);
}


static void _latex_menu_on_usepackage_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_usepackage (self);
}


static void _latex_menu_on_ams_packages_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_ams_packages (self);
}


static void _latex_menu_on_author_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_author (self);
}


static void _latex_menu_on_title_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_title (self);
}


static void _latex_menu_on_begin_document_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_begin_document (self);
}


static void _latex_menu_on_maketitle_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_maketitle (self);
}


static void _latex_menu_on_tableofcontents_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_tableofcontents (self);
}


static void _latex_menu_on_abstract_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_abstract (self);
}


static void _latex_menu_on_include_graphics_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_include_graphics (self);
}


static void _latex_menu_on_input_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_input (self);
}


static void _latex_menu_on_math_env_normal_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_env_normal (self);
}


static void _latex_menu_on_math_env_centered_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_env_centered (self);
}


static void _latex_menu_on_math_env_numbered_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_env_numbered (self);
}


static void _latex_menu_on_math_env_array_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_env_array (self);
}


static void _latex_menu_on_math_env_numbered_array_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_env_numbered_array (self);
}


static void _latex_menu_on_math_superscript_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_superscript (self);
}


static void _latex_menu_on_math_subscript_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_subscript (self);
}


static void _latex_menu_on_math_frac_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_frac (self);
}


static void _latex_menu_on_math_square_root_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_square_root (self);
}


static void _latex_menu_on_math_nth_root_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_nth_root (self);
}


static void _latex_menu_on_math_func_arccos_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_arccos (self);
}


static void _latex_menu_on_math_func_arcsin_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_arcsin (self);
}


static void _latex_menu_on_math_func_arctan_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_arctan (self);
}


static void _latex_menu_on_math_func_cos_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_cos (self);
}


static void _latex_menu_on_math_func_cosh_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_cosh (self);
}


static void _latex_menu_on_math_func_cot_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_cot (self);
}


static void _latex_menu_on_math_func_coth_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_coth (self);
}


static void _latex_menu_on_math_func_csc_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_csc (self);
}


static void _latex_menu_on_math_func_deg_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_deg (self);
}


static void _latex_menu_on_math_func_det_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_det (self);
}


static void _latex_menu_on_math_func_dim_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_dim (self);
}


static void _latex_menu_on_math_func_exp_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_exp (self);
}


static void _latex_menu_on_math_func_gcd_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_gcd (self);
}


static void _latex_menu_on_math_func_hom_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_hom (self);
}


static void _latex_menu_on_math_func_inf_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_inf (self);
}


static void _latex_menu_on_math_func_ker_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_ker (self);
}


static void _latex_menu_on_math_func_lg_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_lg (self);
}


static void _latex_menu_on_math_func_lim_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_lim (self);
}


static void _latex_menu_on_math_func_liminf_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_liminf (self);
}


static void _latex_menu_on_math_func_limsup_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_limsup (self);
}


static void _latex_menu_on_math_func_ln_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_ln (self);
}


static void _latex_menu_on_math_func_log_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_log (self);
}


static void _latex_menu_on_math_func_max_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_max (self);
}


static void _latex_menu_on_math_func_min_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_min (self);
}


static void _latex_menu_on_math_func_sec_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_sec (self);
}


static void _latex_menu_on_math_func_sin_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_sin (self);
}


static void _latex_menu_on_math_func_sinh_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_sinh (self);
}


static void _latex_menu_on_math_func_sup_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_sup (self);
}


static void _latex_menu_on_math_func_tan_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_tan (self);
}


static void _latex_menu_on_math_func_tanh_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_func_tanh (self);
}


static void _latex_menu_on_math_font_style_rm_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_font_style_rm (self);
}


static void _latex_menu_on_math_font_style_it_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_font_style_it (self);
}


static void _latex_menu_on_math_font_style_bf_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_font_style_bf (self);
}


static void _latex_menu_on_math_font_style_sf_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_font_style_sf (self);
}


static void _latex_menu_on_math_font_style_tt_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_font_style_tt (self);
}


static void _latex_menu_on_math_font_style_cal_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_font_style_cal (self);
}


static void _latex_menu_on_math_font_style_bb_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_font_style_bb (self);
}


static void _latex_menu_on_math_font_style_frak_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_font_style_frak (self);
}


static void _latex_menu_on_math_accent_acute_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_accent_acute (self);
}


static void _latex_menu_on_math_accent_grave_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_accent_grave (self);
}


static void _latex_menu_on_math_accent_tilde_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_accent_tilde (self);
}


static void _latex_menu_on_math_accent_bar_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_accent_bar (self);
}


static void _latex_menu_on_math_accent_vec_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_accent_vec (self);
}


static void _latex_menu_on_math_accent_hat_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_accent_hat (self);
}


static void _latex_menu_on_math_accent_check_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_accent_check (self);
}


static void _latex_menu_on_math_accent_breve_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_accent_breve (self);
}


static void _latex_menu_on_math_accent_dot_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_accent_dot (self);
}


static void _latex_menu_on_math_accent_ddot_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_accent_ddot (self);
}


static void _latex_menu_on_math_accent_ring_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_accent_ring (self);
}


static void _latex_menu_on_math_space_small_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_space_small (self);
}


static void _latex_menu_on_math_space_medium_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_space_medium (self);
}


static void _latex_menu_on_math_space_large_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_space_large (self);
}


static void _latex_menu_on_math_space_quad_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_space_quad (self);
}


static void _latex_menu_on_math_space_qquad_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_space_qquad (self);
}


static void _latex_menu_on_math_left_delimiter_1_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_left_delimiter_1 (self);
}


static void _latex_menu_on_math_left_delimiter_2_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_left_delimiter_2 (self);
}


static void _latex_menu_on_math_left_delimiter_3_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_left_delimiter_3 (self);
}


static void _latex_menu_on_math_left_delimiter_4_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_left_delimiter_4 (self);
}


static void _latex_menu_on_math_left_delimiter_5_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_left_delimiter_5 (self);
}


static void _latex_menu_on_math_left_delimiter_6_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_left_delimiter_6 (self);
}


static void _latex_menu_on_math_left_delimiter_7_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_left_delimiter_7 (self);
}


static void _latex_menu_on_math_left_delimiter_8_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_left_delimiter_8 (self);
}


static void _latex_menu_on_math_left_delimiter_9_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_left_delimiter_9 (self);
}


static void _latex_menu_on_math_right_delimiter_1_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_right_delimiter_1 (self);
}


static void _latex_menu_on_math_right_delimiter_2_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_right_delimiter_2 (self);
}


static void _latex_menu_on_math_right_delimiter_3_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_right_delimiter_3 (self);
}


static void _latex_menu_on_math_right_delimiter_4_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_right_delimiter_4 (self);
}


static void _latex_menu_on_math_right_delimiter_5_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_right_delimiter_5 (self);
}


static void _latex_menu_on_math_right_delimiter_6_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_right_delimiter_6 (self);
}


static void _latex_menu_on_math_right_delimiter_7_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_right_delimiter_7 (self);
}


static void _latex_menu_on_math_right_delimiter_8_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_right_delimiter_8 (self);
}


static void _latex_menu_on_math_right_delimiter_9_gtk_action_callback (GtkAction* action, gpointer self) {
	latex_menu_on_math_right_delimiter_9 (self);
}


LatexMenu* latex_menu_construct (GType object_type, MainWindow* main_window) {
	LatexMenu * self = NULL;
	MainWindow* _tmp0_ = NULL;
	GtkAction* sectioning = NULL;
	const gchar* _tmp1_ = NULL;
	GtkAction* _tmp2_ = NULL;
	GtkAction* sizes = NULL;
	const gchar* _tmp3_ = NULL;
	GtkAction* _tmp4_ = NULL;
	GtkAction* references = NULL;
	const gchar* _tmp5_ = NULL;
	GtkAction* _tmp6_ = NULL;
	GtkAction* presentation_env = NULL;
	const gchar* _tmp7_ = NULL;
	GtkAction* _tmp8_ = NULL;
	GtkAction* math_env = NULL;
	const gchar* _tmp9_ = NULL;
	GtkAction* _tmp10_ = NULL;
	GtkAction* math_left_del = NULL;
	const gchar* _tmp11_ = NULL;
	GtkAction* _tmp12_ = NULL;
	GtkAction* math_right_del = NULL;
	const gchar* _tmp13_ = NULL;
	GtkAction* _tmp14_ = NULL;
	g_return_val_if_fail (main_window != NULL, NULL);
	self = (LatexMenu*) g_object_new (object_type, "name", "LatexActionGroup", NULL);
	gtk_action_group_set_translation_domain ((GtkActionGroup*) self, GETTEXT_PACKAGE);
	_tmp0_ = main_window;
	self->priv->main_window = _tmp0_;
	_tmp1_ = _ ("Sectioning");
	_tmp2_ = latex_menu_get_menu_tool_action (self, "SectioningToolItem", _tmp1_, "sectioning-section");
	sectioning = _tmp2_;
	_tmp3_ = _ ("Characters Sizes");
	_tmp4_ = latex_menu_get_menu_tool_action (self, "CharacterSizeToolItem", _tmp3_, "character-size");
	sizes = _tmp4_;
	_tmp5_ = _ ("References");
	_tmp6_ = latex_menu_get_menu_tool_action (self, "ReferencesToolItem", _tmp5_, "references");
	references = _tmp6_;
	_tmp7_ = _ ("Presentation Environments");
	_tmp8_ = latex_menu_get_menu_tool_action (self, "PresentationToolItem", _tmp7_, "presentation");
	presentation_env = _tmp8_;
	_tmp9_ = _ ("Math Environments");
	_tmp10_ = latex_menu_get_menu_tool_action (self, "MathEnvironmentsToolItem", _tmp9_, "math");
	math_env = _tmp10_;
	_tmp11_ = _ ("Left Delimiters");
	_tmp12_ = latex_menu_get_menu_tool_action (self, "MathLeftDelimitersToolItem", _tmp11_, "delimiters-left");
	math_left_del = _tmp12_;
	_tmp13_ = _ ("Right Delimiters");
	_tmp14_ = latex_menu_get_menu_tool_action (self, "MathRightDelimitersToolItem", _tmp13_, "delimiters-right");
	math_right_del = _tmp14_;
	gtk_action_group_add_actions ((GtkActionGroup*) self, LATEX_MENU_latex_action_entries, G_N_ELEMENTS (LATEX_MENU_latex_action_entries), self);
	gtk_action_group_add_action ((GtkActionGroup*) self, sectioning);
	gtk_action_group_add_action ((GtkActionGroup*) self, sizes);
	gtk_action_group_add_action ((GtkActionGroup*) self, references);
	gtk_action_group_add_action ((GtkActionGroup*) self, presentation_env);
	gtk_action_group_add_action ((GtkActionGroup*) self, math_env);
	gtk_action_group_add_action ((GtkActionGroup*) self, math_left_del);
	gtk_action_group_add_action ((GtkActionGroup*) self, math_right_del);
	_g_object_unref0 (math_right_del);
	_g_object_unref0 (math_left_del);
	_g_object_unref0 (math_env);
	_g_object_unref0 (presentation_env);
	_g_object_unref0 (references);
	_g_object_unref0 (sizes);
	_g_object_unref0 (sectioning);
	return self;
}


LatexMenu* latex_menu_new (MainWindow* main_window) {
	return latex_menu_construct (TYPE_LATEX_MENU, main_window);
}


static GtkAction* latex_menu_get_menu_tool_action (LatexMenu* self, const gchar* name, const gchar* label, const gchar* stock_id) {
	GtkAction* result = NULL;
	GtkAction* action = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	MenuToolAction* _tmp4_ = NULL;
	GtkActivatable* menu_tool_button = NULL;
	GtkMenuToolButton* _tmp5_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (name != NULL, NULL);
	_tmp0_ = name;
	_tmp1_ = label;
	_tmp2_ = label;
	_tmp3_ = stock_id;
	_tmp4_ = menu_tool_action_new (_tmp0_, _tmp1_, _tmp2_, _tmp3_);
	action = (GtkAction*) _tmp4_;
	_tmp5_ = (GtkMenuToolButton*) gtk_menu_tool_button_new (NULL, NULL);
	g_object_ref_sink (_tmp5_);
	menu_tool_button = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GTK_TYPE_ACTIVATABLE, GtkActivatable);
	gtk_activatable_set_related_action (menu_tool_button, action);
	result = action;
	_g_object_unref0 (menu_tool_button);
	return result;
}


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = needle;
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
	result = _tmp1_ != NULL;
	return result;
}


static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (old != NULL, NULL);
	g_return_val_if_fail (replacement != NULL, NULL);
	{
		GRegex* regex = NULL;
		const gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GRegex* _tmp3_ = NULL;
		GRegex* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GRegex* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		_tmp0_ = old;
		_tmp1_ = g_regex_escape_string (_tmp0_, -1);
		_tmp2_ = _tmp1_;
		_tmp3_ = g_regex_new (_tmp2_, 0, 0, &_inner_error_);
		_tmp4_ = _tmp3_;
		_g_free0 (_tmp2_);
		regex = _tmp4_;
		if (_inner_error_ != NULL) {
			if (_inner_error_->domain == G_REGEX_ERROR) {
				goto __catch32_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return NULL;
		}
		_tmp6_ = regex;
		_tmp7_ = replacement;
		_tmp8_ = g_regex_replace_literal (_tmp6_, self, (gssize) (-1), 0, _tmp7_, 0, &_inner_error_);
		_tmp5_ = _tmp8_;
		if (_inner_error_ != NULL) {
			_g_regex_unref0 (regex);
			if (_inner_error_->domain == G_REGEX_ERROR) {
				goto __catch32_g_regex_error;
			}
			_g_regex_unref0 (regex);
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return NULL;
		}
		result = _tmp5_;
		_g_regex_unref0 (regex);
		return result;
	}
	goto __finally32;
	__catch32_g_regex_error:
	{
		GError* e = NULL;
		e = _inner_error_;
		_inner_error_ = NULL;
		g_assert_not_reached ();
		_g_error_free0 (e);
	}
	__finally32:
	if (_inner_error_ != NULL) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
		g_clear_error (&_inner_error_);
		return NULL;
	}
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}


static void latex_menu_text_buffer_insert (LatexMenu* self, const gchar* text_before, const gchar* text_after, const gchar* text_if_no_selection) {
	MainWindow* _tmp0_ = NULL;
	DocumentTab* _tmp1_ = NULL;
	DocumentTab* _tmp2_ = NULL;
	Document* active_document = NULL;
	MainWindow* _tmp3_ = NULL;
	Document* _tmp4_ = NULL;
	Document* _tmp5_ = NULL;
	Document* _tmp6_ = NULL;
	GtkTextIter start = {0};
	GtkTextIter end = {0};
	gboolean text_selected = FALSE;
	Document* _tmp7_ = NULL;
	GtkTextIter _tmp8_ = {0};
	GtkTextIter _tmp9_ = {0};
	gboolean _tmp10_ = FALSE;
	gchar* text_before2 = NULL;
	gchar* text_after2 = NULL;
	gboolean _tmp11_ = FALSE;
	const gchar* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp16_ = FALSE;
	Document* _tmp33_ = NULL;
	gboolean _tmp34_ = FALSE;
	Document* _tmp99_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (text_before != NULL);
	g_return_if_fail (text_after != NULL);
	_tmp0_ = self->priv->main_window;
	_tmp1_ = main_window_get_active_tab (_tmp0_);
	_tmp2_ = _tmp1_;
	g_return_if_fail (_tmp2_ != NULL);
	_tmp3_ = self->priv->main_window;
	_tmp4_ = main_window_get_active_document (_tmp3_);
	_tmp5_ = _tmp4_;
	_tmp6_ = _g_object_ref0 (_tmp5_);
	active_document = _tmp6_;
	_tmp7_ = active_document;
	_tmp10_ = gtk_text_buffer_get_selection_bounds ((GtkTextBuffer*) _tmp7_, &_tmp8_, &_tmp9_);
	start = _tmp8_;
	end = _tmp9_;
	text_selected = _tmp10_;
	text_before2 = NULL;
	text_after2 = NULL;
	_tmp12_ = text_before;
	_tmp13_ = string_contains (_tmp12_, "\n");
	if (_tmp13_) {
		_tmp11_ = TRUE;
	} else {
		const gchar* _tmp14_ = NULL;
		gboolean _tmp15_ = FALSE;
		_tmp14_ = text_after;
		_tmp15_ = string_contains (_tmp14_, "\n");
		_tmp11_ = _tmp15_;
	}
	_tmp16_ = _tmp11_;
	if (_tmp16_) {
		gchar* current_indent = NULL;
		Document* _tmp17_ = NULL;
		GtkTextIter _tmp18_ = {0};
		gchar* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		_tmp17_ = active_document;
		_tmp18_ = start;
		_tmp19_ = document_get_current_indentation (_tmp17_, &_tmp18_);
		current_indent = _tmp19_;
		_tmp20_ = current_indent;
		if (g_strcmp0 (_tmp20_, "") != 0) {
			const gchar* _tmp21_ = NULL;
			const gchar* _tmp22_ = NULL;
			const gchar* _tmp23_ = NULL;
			gchar* _tmp24_ = NULL;
			gchar* _tmp25_ = NULL;
			gchar* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
			const gchar* _tmp28_ = NULL;
			const gchar* _tmp29_ = NULL;
			gchar* _tmp30_ = NULL;
			gchar* _tmp31_ = NULL;
			gchar* _tmp32_ = NULL;
			_tmp21_ = text_before;
			_tmp22_ = current_indent;
			_tmp23_ = string_to_string (_tmp22_);
			_tmp24_ = g_strconcat ("\n", _tmp23_, NULL);
			_tmp25_ = _tmp24_;
			_tmp26_ = string_replace (_tmp21_, "\n", _tmp25_);
			_g_free0 (text_before2);
			text_before2 = _tmp26_;
			_g_free0 (_tmp25_);
			_tmp27_ = text_after;
			_tmp28_ = current_indent;
			_tmp29_ = string_to_string (_tmp28_);
			_tmp30_ = g_strconcat ("\n", _tmp29_, NULL);
			_tmp31_ = _tmp30_;
			_tmp32_ = string_replace (_tmp27_, "\n", _tmp31_);
			_g_free0 (text_after2);
			text_after2 = _tmp32_;
			_g_free0 (_tmp31_);
		}
		_g_free0 (current_indent);
	}
	_tmp33_ = active_document;
	gtk_text_buffer_begin_user_action ((GtkTextBuffer*) _tmp33_);
	_tmp34_ = text_selected;
	if (_tmp34_) {
		GtkTextMark* mark_end = NULL;
		Document* _tmp35_ = NULL;
		GtkTextIter _tmp36_ = {0};
		GtkTextMark* _tmp37_ = NULL;
		GtkTextMark* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		const gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
		const gchar* _tmp42_ = NULL;
		Document* _tmp45_ = NULL;
		const gchar* _tmp46_ = NULL;
		Document* _tmp47_ = NULL;
		GtkTextMark* _tmp48_ = NULL;
		GtkTextIter _tmp49_ = {0};
		gchar* _tmp50_ = NULL;
		const gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		const gchar* _tmp53_ = NULL;
		Document* _tmp56_ = NULL;
		const gchar* _tmp57_ = NULL;
		Document* _tmp58_ = NULL;
		GtkTextMark* _tmp59_ = NULL;
		GtkTextIter _tmp60_ = {0};
		Document* _tmp61_ = NULL;
		GtkTextMark* _tmp62_ = NULL;
		Document* _tmp63_ = NULL;
		GtkTextIter _tmp64_ = {0};
		_tmp35_ = active_document;
		_tmp36_ = end;
		_tmp37_ = gtk_text_buffer_create_mark ((GtkTextBuffer*) _tmp35_, NULL, &_tmp36_, FALSE);
		_tmp38_ = _g_object_ref0 (_tmp37_);
		mark_end = _tmp38_;
		_tmp40_ = text_before2;
		_tmp41_ = g_strdup (_tmp40_);
		_tmp39_ = _tmp41_;
		_tmp42_ = _tmp39_;
		if (_tmp42_ == NULL) {
			const gchar* _tmp43_ = NULL;
			gchar* _tmp44_ = NULL;
			_tmp43_ = text_before;
			_tmp44_ = g_strdup (_tmp43_);
			_g_free0 (_tmp39_);
			_tmp39_ = _tmp44_;
		}
		_tmp45_ = active_document;
		_tmp46_ = _tmp39_;
		document_insert (_tmp45_, &start, _tmp46_, -1);
		_tmp47_ = active_document;
		_tmp48_ = mark_end;
		gtk_text_buffer_get_iter_at_mark ((GtkTextBuffer*) _tmp47_, &_tmp49_, _tmp48_);
		end = _tmp49_;
		_tmp51_ = text_after2;
		_tmp52_ = g_strdup (_tmp51_);
		_tmp50_ = _tmp52_;
		_tmp53_ = _tmp50_;
		if (_tmp53_ == NULL) {
			const gchar* _tmp54_ = NULL;
			gchar* _tmp55_ = NULL;
			_tmp54_ = text_after;
			_tmp55_ = g_strdup (_tmp54_);
			_g_free0 (_tmp50_);
			_tmp50_ = _tmp55_;
		}
		_tmp56_ = active_document;
		_tmp57_ = _tmp50_;
		document_insert (_tmp56_, &end, _tmp57_, -1);
		_tmp58_ = active_document;
		_tmp59_ = mark_end;
		gtk_text_buffer_get_iter_at_mark ((GtkTextBuffer*) _tmp58_, &_tmp60_, _tmp59_);
		end = _tmp60_;
		_tmp61_ = active_document;
		_tmp62_ = mark_end;
		gtk_text_buffer_delete_mark ((GtkTextBuffer*) _tmp61_, _tmp62_);
		_tmp63_ = active_document;
		_tmp64_ = end;
		gtk_text_buffer_place_cursor ((GtkTextBuffer*) _tmp63_, &_tmp64_);
		_g_free0 (_tmp50_);
		_g_free0 (_tmp39_);
		_g_object_unref0 (mark_end);
	} else {
		const gchar* _tmp65_ = NULL;
		_tmp65_ = text_if_no_selection;
		if (_tmp65_ != NULL) {
			Document* _tmp66_ = NULL;
			const gchar* _tmp67_ = NULL;
			_tmp66_ = active_document;
			_tmp67_ = text_if_no_selection;
			gtk_text_buffer_insert_at_cursor ((GtkTextBuffer*) _tmp66_, _tmp67_, -1);
		} else {
			gchar* _tmp68_ = NULL;
			const gchar* _tmp69_ = NULL;
			gchar* _tmp70_ = NULL;
			const gchar* _tmp71_ = NULL;
			Document* _tmp74_ = NULL;
			const gchar* _tmp75_ = NULL;
			GtkTextIter between = {0};
			Document* _tmp76_ = NULL;
			Document* _tmp77_ = NULL;
			GtkTextMark* _tmp78_ = NULL;
			GtkTextIter _tmp79_ = {0};
			GtkTextMark* mark = NULL;
			Document* _tmp80_ = NULL;
			GtkTextIter _tmp81_ = {0};
			GtkTextMark* _tmp82_ = NULL;
			GtkTextMark* _tmp83_ = NULL;
			gchar* _tmp84_ = NULL;
			const gchar* _tmp85_ = NULL;
			gchar* _tmp86_ = NULL;
			const gchar* _tmp87_ = NULL;
			Document* _tmp90_ = NULL;
			const gchar* _tmp91_ = NULL;
			Document* _tmp92_ = NULL;
			GtkTextMark* _tmp93_ = NULL;
			GtkTextIter _tmp94_ = {0};
			Document* _tmp95_ = NULL;
			GtkTextMark* _tmp96_ = NULL;
			Document* _tmp97_ = NULL;
			GtkTextIter _tmp98_ = {0};
			_tmp69_ = text_before2;
			_tmp70_ = g_strdup (_tmp69_);
			_tmp68_ = _tmp70_;
			_tmp71_ = _tmp68_;
			if (_tmp71_ == NULL) {
				const gchar* _tmp72_ = NULL;
				gchar* _tmp73_ = NULL;
				_tmp72_ = text_before;
				_tmp73_ = g_strdup (_tmp72_);
				_g_free0 (_tmp68_);
				_tmp68_ = _tmp73_;
			}
			_tmp74_ = active_document;
			_tmp75_ = _tmp68_;
			gtk_text_buffer_insert_at_cursor ((GtkTextBuffer*) _tmp74_, _tmp75_, -1);
			_tmp76_ = active_document;
			_tmp77_ = active_document;
			_tmp78_ = gtk_text_buffer_get_insert ((GtkTextBuffer*) _tmp77_);
			gtk_text_buffer_get_iter_at_mark ((GtkTextBuffer*) _tmp76_, &_tmp79_, _tmp78_);
			between = _tmp79_;
			_tmp80_ = active_document;
			_tmp81_ = between;
			_tmp82_ = gtk_text_buffer_create_mark ((GtkTextBuffer*) _tmp80_, NULL, &_tmp81_, TRUE);
			_tmp83_ = _g_object_ref0 (_tmp82_);
			mark = _tmp83_;
			_tmp85_ = text_after2;
			_tmp86_ = g_strdup (_tmp85_);
			_tmp84_ = _tmp86_;
			_tmp87_ = _tmp84_;
			if (_tmp87_ == NULL) {
				const gchar* _tmp88_ = NULL;
				gchar* _tmp89_ = NULL;
				_tmp88_ = text_after;
				_tmp89_ = g_strdup (_tmp88_);
				_g_free0 (_tmp84_);
				_tmp84_ = _tmp89_;
			}
			_tmp90_ = active_document;
			_tmp91_ = _tmp84_;
			gtk_text_buffer_insert_at_cursor ((GtkTextBuffer*) _tmp90_, _tmp91_, -1);
			_tmp92_ = active_document;
			_tmp93_ = mark;
			gtk_text_buffer_get_iter_at_mark ((GtkTextBuffer*) _tmp92_, &_tmp94_, _tmp93_);
			between = _tmp94_;
			_tmp95_ = active_document;
			_tmp96_ = mark;
			gtk_text_buffer_delete_mark ((GtkTextBuffer*) _tmp95_, _tmp96_);
			_tmp97_ = active_document;
			_tmp98_ = between;
			gtk_text_buffer_place_cursor ((GtkTextBuffer*) _tmp97_, &_tmp98_);
			_g_free0 (_tmp84_);
			_g_object_unref0 (mark);
			_g_free0 (_tmp68_);
		}
	}
	_tmp99_ = active_document;
	gtk_text_buffer_end_user_action ((GtkTextBuffer*) _tmp99_);
	_g_free0 (text_after2);
	_g_free0 (text_before2);
	_g_object_unref0 (active_document);
}


static gchar* latex_menu_get_indentation (LatexMenu* self) {
	gchar* result = NULL;
	MainWindow* _tmp0_ = NULL;
	DocumentView* _tmp1_ = NULL;
	DocumentView* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->main_window;
	_tmp1_ = main_window_get_active_view (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = document_view_get_indentation_style (_tmp2_);
	result = _tmp3_;
	return result;
}


static void latex_menu_insert_character_style (LatexMenu* self, const gchar* style) {
	MainWindow* _tmp0_ = NULL;
	DocumentTab* _tmp1_ = NULL;
	DocumentTab* _tmp2_ = NULL;
	MainWindow* _tmp3_ = NULL;
	Document* _tmp4_ = NULL;
	Document* _tmp5_ = NULL;
	SelectionType _tmp6_ = 0;
	g_return_if_fail (self != NULL);
	g_return_if_fail (style != NULL);
	_tmp0_ = self->priv->main_window;
	_tmp1_ = main_window_get_active_tab (_tmp0_);
	_tmp2_ = _tmp1_;
	g_return_if_fail (_tmp2_ != NULL);
	_tmp3_ = self->priv->main_window;
	_tmp4_ = main_window_get_active_document (_tmp3_);
	_tmp5_ = _tmp4_;
	_tmp6_ = document_get_selection_type (_tmp5_);
	if (_tmp6_ == SELECTION_TYPE_MULTIPLE_LINES) {
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		_tmp7_ = style;
		_tmp8_ = string_to_string (_tmp7_);
		_tmp9_ = g_strconcat ("\\begin{", _tmp8_, "}\n", NULL);
		_tmp10_ = _tmp9_;
		_tmp11_ = style;
		_tmp12_ = string_to_string (_tmp11_);
		_tmp13_ = g_strconcat ("\n\\end{", _tmp12_, "}", NULL);
		_tmp14_ = _tmp13_;
		latex_menu_text_buffer_insert (self, _tmp10_, _tmp14_, NULL);
		_g_free0 (_tmp14_);
		_g_free0 (_tmp10_);
	} else {
		const gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		_tmp15_ = style;
		_tmp16_ = string_to_string (_tmp15_);
		_tmp17_ = g_strconcat ("{\\", _tmp16_, " ", NULL);
		_tmp18_ = _tmp17_;
		_tmp19_ = style;
		_tmp20_ = string_to_string (_tmp19_);
		_tmp21_ = g_strconcat ("\\", _tmp20_, " ", NULL);
		_tmp22_ = _tmp21_;
		latex_menu_text_buffer_insert (self, _tmp18_, "}", _tmp22_);
		_g_free0 (_tmp22_);
		_g_free0 (_tmp18_);
	}
}


void latex_menu_on_sectioning_part (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\part{", "}", NULL);
}


void latex_menu_on_sectioning_chapter (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\chapter{", "}", NULL);
}


void latex_menu_on_sectioning_section (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\section{", "}", NULL);
}


void latex_menu_on_sectioning_subsection (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\subsection{", "}", NULL);
}


void latex_menu_on_sectioning_subsubsection (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\subsubsection{", "}", NULL);
}


void latex_menu_on_sectioning_paragraph (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\paragraph{", "}", NULL);
}


void latex_menu_on_sectioning_subparagraph (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\subparagraph{", "}", NULL);
}


void latex_menu_on_ref_label (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\label{", "} ", NULL);
}


void latex_menu_on_ref_ref (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\ref{", "} ", NULL);
}


void latex_menu_on_ref_pageref (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\pageref{", "} ", NULL);
}


void latex_menu_on_ref_index (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\index{", "} ", NULL);
}


void latex_menu_on_ref_footnote (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\footnote{", "} ", NULL);
}


void latex_menu_on_ref_cite (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\cite{", "} ", NULL);
}


void latex_menu_on_env_center (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{center}\n", "\n\\end{center}", NULL);
}


void latex_menu_on_env_left (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{flushleft}\n", "\n\\end{flushleft}", NULL);
}


void latex_menu_on_env_right (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{flushright}\n", "\n\\end{flushright}", NULL);
}


void latex_menu_on_env_figure (LatexMenu* self) {
	gchar* indent = NULL;
	gchar* _tmp0_ = NULL;
	gchar* before_cursor = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* after_cursor = NULL;
	const gchar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	const gchar* _tmp24_ = NULL;
	gchar* _tmp25_ = NULL;
	gchar* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	gchar* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = latex_menu_get_indentation (self);
	indent = _tmp0_;
	_tmp1_ = string_to_string (indent);
	_tmp2_ = g_strconcat (_tmp1_, "\\begin{center}\n", NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strconcat ("\\begin{figure}\n", _tmp3_, NULL);
	_tmp5_ = _tmp4_;
	_tmp6_ = string_to_string (indent);
	_tmp7_ = string_to_string (indent);
	_tmp8_ = g_strconcat (_tmp6_, _tmp7_, "\\includegraphics{", NULL);
	_tmp9_ = _tmp8_;
	_tmp10_ = g_strconcat (_tmp5_, _tmp9_, NULL);
	_tmp11_ = _tmp10_;
	_g_free0 (_tmp9_);
	_g_free0 (_tmp5_);
	_g_free0 (_tmp3_);
	before_cursor = _tmp11_;
	_tmp12_ = string_to_string (indent);
	_tmp13_ = string_to_string (indent);
	_tmp14_ = g_strconcat (_tmp12_, _tmp13_, "\\caption{}\n", NULL);
	_tmp15_ = _tmp14_;
	_tmp16_ = g_strconcat ("}\n", _tmp15_, NULL);
	_tmp17_ = _tmp16_;
	_tmp18_ = string_to_string (indent);
	_tmp19_ = string_to_string (indent);
	_tmp20_ = g_strconcat (_tmp18_, _tmp19_, "\\label{fig:}\n", NULL);
	_tmp21_ = _tmp20_;
	_tmp22_ = g_strconcat (_tmp17_, _tmp21_, NULL);
	_tmp23_ = _tmp22_;
	_tmp24_ = string_to_string (indent);
	_tmp25_ = g_strconcat (_tmp24_, "\\end{center}\n", NULL);
	_tmp26_ = _tmp25_;
	_tmp27_ = g_strconcat (_tmp23_, _tmp26_, NULL);
	_tmp28_ = _tmp27_;
	_tmp29_ = g_strconcat (_tmp28_, "\\end{figure}", NULL);
	_tmp30_ = _tmp29_;
	_g_free0 (_tmp28_);
	_g_free0 (_tmp26_);
	_g_free0 (_tmp23_);
	_g_free0 (_tmp21_);
	_g_free0 (_tmp17_);
	_g_free0 (_tmp15_);
	after_cursor = _tmp30_;
	latex_menu_text_buffer_insert (self, before_cursor, after_cursor, NULL);
	_g_free0 (after_cursor);
	_g_free0 (before_cursor);
	_g_free0 (indent);
}


void latex_menu_on_env_table (LatexMenu* self) {
	gchar* indent = NULL;
	gchar* _tmp0_ = NULL;
	gchar* before_cursor = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* after_cursor = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	const gchar* _tmp24_ = NULL;
	const gchar* _tmp25_ = NULL;
	const gchar* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	gchar* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	const gchar* _tmp31_ = NULL;
	const gchar* _tmp32_ = NULL;
	const gchar* _tmp33_ = NULL;
	gchar* _tmp34_ = NULL;
	gchar* _tmp35_ = NULL;
	gchar* _tmp36_ = NULL;
	gchar* _tmp37_ = NULL;
	const gchar* _tmp38_ = NULL;
	const gchar* _tmp39_ = NULL;
	gchar* _tmp40_ = NULL;
	gchar* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	gchar* _tmp43_ = NULL;
	const gchar* _tmp44_ = NULL;
	gchar* _tmp45_ = NULL;
	gchar* _tmp46_ = NULL;
	gchar* _tmp47_ = NULL;
	gchar* _tmp48_ = NULL;
	gchar* _tmp49_ = NULL;
	gchar* _tmp50_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = latex_menu_get_indentation (self);
	indent = _tmp0_;
	_tmp1_ = string_to_string (indent);
	_tmp2_ = g_strconcat (_tmp1_, "\\caption{", NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strconcat ("\\begin{table}\n", _tmp3_, NULL);
	_tmp5_ = _tmp4_;
	_g_free0 (_tmp3_);
	before_cursor = _tmp5_;
	_tmp6_ = string_to_string (indent);
	_tmp7_ = g_strconcat (_tmp6_, "\\label{tab:}\n", NULL);
	_tmp8_ = _tmp7_;
	_tmp9_ = g_strconcat ("}\n", _tmp8_, NULL);
	_tmp10_ = _tmp9_;
	_tmp11_ = g_strconcat (_tmp10_, "\n", NULL);
	_tmp12_ = _tmp11_;
	_tmp13_ = string_to_string (indent);
	_tmp14_ = g_strconcat (_tmp13_, "\\begin{center}\n", NULL);
	_tmp15_ = _tmp14_;
	_tmp16_ = g_strconcat (_tmp12_, _tmp15_, NULL);
	_tmp17_ = _tmp16_;
	_tmp18_ = string_to_string (indent);
	_tmp19_ = string_to_string (indent);
	_tmp20_ = g_strconcat (_tmp18_, _tmp19_, "\\begin{tabular}{cc}\n", NULL);
	_tmp21_ = _tmp20_;
	_tmp22_ = g_strconcat (_tmp17_, _tmp21_, NULL);
	_tmp23_ = _tmp22_;
	_tmp24_ = string_to_string (indent);
	_tmp25_ = string_to_string (indent);
	_tmp26_ = string_to_string (indent);
	_tmp27_ = g_strconcat (_tmp24_, _tmp25_, _tmp26_, " & \\\\\n", NULL);
	_tmp28_ = _tmp27_;
	_tmp29_ = g_strconcat (_tmp23_, _tmp28_, NULL);
	_tmp30_ = _tmp29_;
	_tmp31_ = string_to_string (indent);
	_tmp32_ = string_to_string (indent);
	_tmp33_ = string_to_string (indent);
	_tmp34_ = g_strconcat (_tmp31_, _tmp32_, _tmp33_, " & \\\\\n", NULL);
	_tmp35_ = _tmp34_;
	_tmp36_ = g_strconcat (_tmp30_, _tmp35_, NULL);
	_tmp37_ = _tmp36_;
	_tmp38_ = string_to_string (indent);
	_tmp39_ = string_to_string (indent);
	_tmp40_ = g_strconcat (_tmp38_, _tmp39_, "\\end{tabular}\n", NULL);
	_tmp41_ = _tmp40_;
	_tmp42_ = g_strconcat (_tmp37_, _tmp41_, NULL);
	_tmp43_ = _tmp42_;
	_tmp44_ = string_to_string (indent);
	_tmp45_ = g_strconcat (_tmp44_, "\\end{center}\n", NULL);
	_tmp46_ = _tmp45_;
	_tmp47_ = g_strconcat (_tmp43_, _tmp46_, NULL);
	_tmp48_ = _tmp47_;
	_tmp49_ = g_strconcat (_tmp48_, "\\end{table}", NULL);
	_tmp50_ = _tmp49_;
	_g_free0 (_tmp48_);
	_g_free0 (_tmp46_);
	_g_free0 (_tmp43_);
	_g_free0 (_tmp41_);
	_g_free0 (_tmp37_);
	_g_free0 (_tmp35_);
	_g_free0 (_tmp30_);
	_g_free0 (_tmp28_);
	_g_free0 (_tmp23_);
	_g_free0 (_tmp21_);
	_g_free0 (_tmp17_);
	_g_free0 (_tmp15_);
	_g_free0 (_tmp12_);
	_g_free0 (_tmp10_);
	_g_free0 (_tmp8_);
	after_cursor = _tmp50_;
	latex_menu_text_buffer_insert (self, before_cursor, after_cursor, NULL);
	_g_free0 (after_cursor);
	_g_free0 (before_cursor);
	_g_free0 (indent);
}


void latex_menu_on_env_quote (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{quote}\n", "\n\\end{quote}", NULL);
}


void latex_menu_on_env_quotation (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{quotation}\n", "\n\\end{quotation}", NULL);
}


void latex_menu_on_env_verse (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{verse}\n", "\n\\end{verse}", NULL);
}


void latex_menu_on_env_verbatim (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{verbatim}\n", "\n\\end{verbatim}", NULL);
}


void latex_menu_on_env_minipage (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{minipage}\n", "\n\\end{minipage}", NULL);
}


void latex_menu_on_env_titlepage (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{titlepage}\n", "\n\\end{titlepage}", NULL);
}


void latex_menu_on_list_env_itemize (LatexMenu* self) {
	gchar* indent = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = latex_menu_get_indentation (self);
	indent = _tmp0_;
	_tmp1_ = string_to_string (indent);
	_tmp2_ = g_strconcat ("\\begin{itemize}\n", _tmp1_, "\\item ", NULL);
	_tmp3_ = _tmp2_;
	latex_menu_text_buffer_insert (self, _tmp3_, "\n\\end{itemize}", NULL);
	_g_free0 (_tmp3_);
	_g_free0 (indent);
}


void latex_menu_on_list_env_enumerate (LatexMenu* self) {
	gchar* indent = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = latex_menu_get_indentation (self);
	indent = _tmp0_;
	_tmp1_ = string_to_string (indent);
	_tmp2_ = g_strconcat ("\\begin{enumerate}\n", _tmp1_, "\\item ", NULL);
	_tmp3_ = _tmp2_;
	latex_menu_text_buffer_insert (self, _tmp3_, "\n\\end{enumerate}", NULL);
	_g_free0 (_tmp3_);
	_g_free0 (indent);
}


void latex_menu_on_list_env_description (LatexMenu* self) {
	gchar* indent = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = latex_menu_get_indentation (self);
	indent = _tmp0_;
	_tmp1_ = string_to_string (indent);
	_tmp2_ = g_strconcat ("\\begin{description}\n", _tmp1_, "\\item[", NULL);
	_tmp3_ = _tmp2_;
	latex_menu_text_buffer_insert (self, _tmp3_, "] \n\\end{description}", NULL);
	_g_free0 (_tmp3_);
	_g_free0 (indent);
}


void latex_menu_on_list_env_list (LatexMenu* self) {
	gchar* indent = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = latex_menu_get_indentation (self);
	indent = _tmp0_;
	_tmp1_ = string_to_string (indent);
	_tmp2_ = g_strconcat ("}{}\n", _tmp1_, "\\item \n\\end{list}", NULL);
	_tmp3_ = _tmp2_;
	latex_menu_text_buffer_insert (self, "\\begin{list}{", _tmp3_, NULL);
	_g_free0 (_tmp3_);
	_g_free0 (indent);
}


void latex_menu_on_list_env_item (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\item ", "", NULL);
}


void latex_menu_on_size_tiny (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "tiny");
}


void latex_menu_on_size_scriptsize (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "scriptsize");
}


void latex_menu_on_size_footnotesize (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "footnotesize");
}


void latex_menu_on_size_small (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "small");
}


void latex_menu_on_size_normalsize (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "normalsize");
}


void latex_menu_on_size_large (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "large");
}


void latex_menu_on_size_Large (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "Large");
}


void latex_menu_on_size_LARGE (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "LARGE");
}


void latex_menu_on_size_huge (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "huge");
}


void latex_menu_on_size_Huge (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "Huge");
}


void latex_menu_on_text_bold (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\textbf{", "}", NULL);
}


void latex_menu_on_text_italic (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\textit{", "}", NULL);
}


void latex_menu_on_text_typewriter (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\texttt{", "}", NULL);
}


void latex_menu_on_text_slanted (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\textsl{", "}", NULL);
}


void latex_menu_on_text_small_caps (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\textsc{", "}", NULL);
}


void latex_menu_on_text_sans_serif (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\textsf{", "}", NULL);
}


void latex_menu_on_text_emph (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\emph{", "}", NULL);
}


void latex_menu_on_text_underline (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\underline{", "}", NULL);
}


void latex_menu_on_text_font_family_roman (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "rmfamily");
}


void latex_menu_on_text_font_family_sans_serif (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "sffamily");
}


void latex_menu_on_text_font_family_monospace (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "ttfamily");
}


void latex_menu_on_text_font_series_medium (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "mdseries");
}


void latex_menu_on_text_font_series_bold (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "bfseries");
}


void latex_menu_on_text_font_shape_upright (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "upshape");
}


void latex_menu_on_text_font_shape_italic (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "itshape");
}


void latex_menu_on_text_font_shape_slanted (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "slshape");
}


void latex_menu_on_text_font_shape_small_caps (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_insert_character_style (self, "scshape");
}


void latex_menu_on_tabular_tabbing (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{tabbing}\n", "\n\\end{tabbing}", NULL);
}


void latex_menu_on_tabular_tabular (LatexMenu* self) {
	gchar* indent = NULL;
	gchar* _tmp0_ = NULL;
	gchar* before_cursor = NULL;
	gchar* _tmp1_ = NULL;
	gchar* after_cursor = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = latex_menu_get_indentation (self);
	indent = _tmp0_;
	_tmp1_ = g_strdup ("\\begin{tabular}{cc");
	before_cursor = _tmp1_;
	_tmp2_ = string_to_string (indent);
	_tmp3_ = g_strconcat (_tmp2_, " & \\\\\n", NULL);
	_tmp4_ = _tmp3_;
	_tmp5_ = g_strconcat ("}\n", _tmp4_, NULL);
	_tmp6_ = _tmp5_;
	_tmp7_ = string_to_string (indent);
	_tmp8_ = g_strconcat (_tmp7_, " & \\\\\n", NULL);
	_tmp9_ = _tmp8_;
	_tmp10_ = g_strconcat (_tmp6_, _tmp9_, NULL);
	_tmp11_ = _tmp10_;
	_tmp12_ = g_strconcat (_tmp11_, "\\end{tabular}", NULL);
	_tmp13_ = _tmp12_;
	_g_free0 (_tmp11_);
	_g_free0 (_tmp9_);
	_g_free0 (_tmp6_);
	_g_free0 (_tmp4_);
	after_cursor = _tmp13_;
	latex_menu_text_buffer_insert (self, before_cursor, after_cursor, NULL);
	_g_free0 (after_cursor);
	_g_free0 (before_cursor);
	_g_free0 (indent);
}


void latex_menu_on_tabular_multicolumn (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\multicolumn{}{}{", "}", NULL);
}


void latex_menu_on_tabular_hline (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\hline ", "", NULL);
}


void latex_menu_on_tabular_vline (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\vline ", "", NULL);
}


void latex_menu_on_tabular_cline (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\cline{", "-}", NULL);
}


void latex_menu_on_spacing_new_line (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\\\\n", "", NULL);
}


void latex_menu_on_spacing_new_page (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\newpage\n", "", NULL);
}


void latex_menu_on_spacing_line_break (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\linebreak\n", "", NULL);
}


void latex_menu_on_spacing_page_break (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\pagebreak\n", "", NULL);
}


void latex_menu_on_spacing_bigskip (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\bigskip ", "", NULL);
}


void latex_menu_on_spacing_medskip (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\medskip ", "", NULL);
}


void latex_menu_on_spacing_hspace (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\hspace{", "}", NULL);
}


void latex_menu_on_spacing_vspace (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\vspace{", "}", NULL);
}


void latex_menu_on_spacing_noindent (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\noindent ", "", NULL);
}


void latex_menu_on_accent0 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\'{", "}", NULL);
}


void latex_menu_on_accent1 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\`{", "}", NULL);
}


void latex_menu_on_accent2 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\^{", "}", NULL);
}


void latex_menu_on_accent3 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\\"{", "}", NULL);
}


void latex_menu_on_accent4 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\~{", "}", NULL);
}


void latex_menu_on_accent5 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\={", "}", NULL);
}


void latex_menu_on_accent6 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\.{", "}", NULL);
}


void latex_menu_on_accent7 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\v{", "}", NULL);
}


void latex_menu_on_accent8 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\u{", "}", NULL);
}


void latex_menu_on_accent9 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\H{", "}", NULL);
}


void latex_menu_on_accent10 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\c{", "}", NULL);
}


void latex_menu_on_accent11 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\k{", "}", NULL);
}


void latex_menu_on_accent12 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\d{", "}", NULL);
}


void latex_menu_on_accent13 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\b{", "}", NULL);
}


void latex_menu_on_accent14 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\r{", "}", NULL);
}


void latex_menu_on_accent15 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\t{", "}", NULL);
}


void latex_menu_on_present_frame (LatexMenu* self) {
	gchar* indent = NULL;
	gchar* _tmp0_ = NULL;
	gchar* begin_frame = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* end_frame = NULL;
	gchar* _tmp11_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = latex_menu_get_indentation (self);
	indent = _tmp0_;
	_tmp1_ = string_to_string (indent);
	_tmp2_ = g_strconcat (_tmp1_, "\\frametitle{}\n", NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strconcat ("\\begin{frame}\n", _tmp3_, NULL);
	_tmp5_ = _tmp4_;
	_tmp6_ = string_to_string (indent);
	_tmp7_ = g_strconcat (_tmp6_, "\\framesubtitle{}\n", NULL);
	_tmp8_ = _tmp7_;
	_tmp9_ = g_strconcat (_tmp5_, _tmp8_, NULL);
	_tmp10_ = _tmp9_;
	_g_free0 (_tmp8_);
	_g_free0 (_tmp5_);
	_g_free0 (_tmp3_);
	begin_frame = _tmp10_;
	_tmp11_ = g_strdup ("\n\\end{frame}");
	end_frame = _tmp11_;
	latex_menu_text_buffer_insert (self, begin_frame, end_frame, NULL);
	_g_free0 (end_frame);
	_g_free0 (begin_frame);
	_g_free0 (indent);
}


void latex_menu_on_present_columns (LatexMenu* self) {
	gchar* indent = NULL;
	gchar* _tmp0_ = NULL;
	gchar* begin_columns = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* end_columns = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = latex_menu_get_indentation (self);
	indent = _tmp0_;
	_tmp1_ = string_to_string (indent);
	_tmp2_ = g_strconcat (_tmp1_, "\\begin{column}{.5\\textwidth}\n", NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strconcat ("\\begin{columns}\n", _tmp3_, NULL);
	_tmp5_ = _tmp4_;
	_g_free0 (_tmp3_);
	begin_columns = _tmp5_;
	_tmp6_ = string_to_string (indent);
	_tmp7_ = g_strconcat ("\n", _tmp6_, "\\end{column}\n", NULL);
	_tmp8_ = _tmp7_;
	_tmp9_ = string_to_string (indent);
	_tmp10_ = g_strconcat (_tmp9_, "\\begin{column}{.5\\textwidth}\n\n", NULL);
	_tmp11_ = _tmp10_;
	_tmp12_ = g_strconcat (_tmp8_, _tmp11_, NULL);
	_tmp13_ = _tmp12_;
	_tmp14_ = string_to_string (indent);
	_tmp15_ = g_strconcat (_tmp14_, "\\end{column}\n", NULL);
	_tmp16_ = _tmp15_;
	_tmp17_ = g_strconcat (_tmp13_, _tmp16_, NULL);
	_tmp18_ = _tmp17_;
	_tmp19_ = g_strconcat (_tmp18_, "\\end{columns}", NULL);
	_tmp20_ = _tmp19_;
	_g_free0 (_tmp18_);
	_g_free0 (_tmp16_);
	_g_free0 (_tmp13_);
	_g_free0 (_tmp11_);
	_g_free0 (_tmp8_);
	end_columns = _tmp20_;
	latex_menu_text_buffer_insert (self, begin_columns, end_columns, NULL);
	_g_free0 (end_columns);
	_g_free0 (begin_columns);
	_g_free0 (indent);
}


void latex_menu_on_present_block (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{block}{}\n", "\n\\end{block}", NULL);
}


void latex_menu_on_documentclass (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\documentclass{", "}", NULL);
}


void latex_menu_on_usepackage (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\usepackage{", "}", NULL);
}


void latex_menu_on_ams_packages (LatexMenu* self) {
	gchar* packages = NULL;
	gchar* _tmp0_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup ("\\usepackage{amsmath}\n" "\\usepackage{amsfonts}\n" "\\usepackage{amssymb}");
	packages = _tmp0_;
	latex_menu_text_buffer_insert (self, packages, "", NULL);
	_g_free0 (packages);
}


void latex_menu_on_author (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\author{", "}", NULL);
}


void latex_menu_on_title (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\title{", "}", NULL);
}


void latex_menu_on_begin_document (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{document}\n", "\n\\end{document}", NULL);
}


void latex_menu_on_maketitle (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\maketitle", "", NULL);
}


void latex_menu_on_tableofcontents (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\tableofcontents", "", NULL);
}


void latex_menu_on_abstract (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{abstract}\n", "\n\\end{abstract}", NULL);
}


void latex_menu_on_include_graphics (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\includegraphics{", "}", NULL);
}


void latex_menu_on_input (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\input{", "}", NULL);
}


void latex_menu_on_math_env_normal (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "$ ", " $", NULL);
}


void latex_menu_on_math_env_centered (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\[ ", " \\]", NULL);
}


void latex_menu_on_math_env_numbered (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{equation}\n", "\n\\end{equation}", NULL);
}


void latex_menu_on_math_env_array (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{align*}\n", "\n\\end{align*}", NULL);
}


void latex_menu_on_math_env_numbered_array (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\begin{align}\n", "\n\\end{align}", NULL);
}


void latex_menu_on_math_superscript (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "^{", "}", NULL);
}


void latex_menu_on_math_subscript (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "_{", "}", NULL);
}


void latex_menu_on_math_frac (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\frac{", "}{}", NULL);
}


void latex_menu_on_math_square_root (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\sqrt{", "}", NULL);
}


void latex_menu_on_math_nth_root (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\sqrt[]{", "}", NULL);
}


void latex_menu_on_math_func_arccos (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\arccos ", "", NULL);
}


void latex_menu_on_math_func_arcsin (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\arcsin ", "", NULL);
}


void latex_menu_on_math_func_arctan (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\arctan ", "", NULL);
}


void latex_menu_on_math_func_cos (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\cos ", "", NULL);
}


void latex_menu_on_math_func_cosh (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\cosh ", "", NULL);
}


void latex_menu_on_math_func_cot (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\cot ", "", NULL);
}


void latex_menu_on_math_func_coth (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\coth ", "", NULL);
}


void latex_menu_on_math_func_csc (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\csc ", "", NULL);
}


void latex_menu_on_math_func_deg (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\deg ", "", NULL);
}


void latex_menu_on_math_func_det (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\det ", "", NULL);
}


void latex_menu_on_math_func_dim (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\dim ", "", NULL);
}


void latex_menu_on_math_func_exp (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\exp ", "", NULL);
}


void latex_menu_on_math_func_gcd (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\gcd ", "", NULL);
}


void latex_menu_on_math_func_hom (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\hom ", "", NULL);
}


void latex_menu_on_math_func_inf (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\inf ", "", NULL);
}


void latex_menu_on_math_func_ker (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\ker ", "", NULL);
}


void latex_menu_on_math_func_lg (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\lg ", "", NULL);
}


void latex_menu_on_math_func_lim (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\lim ", "", NULL);
}


void latex_menu_on_math_func_liminf (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\liminf ", "", NULL);
}


void latex_menu_on_math_func_limsup (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\limsup ", "", NULL);
}


void latex_menu_on_math_func_ln (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\ln ", "", NULL);
}


void latex_menu_on_math_func_log (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\log ", "", NULL);
}


void latex_menu_on_math_func_max (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\max ", "", NULL);
}


void latex_menu_on_math_func_min (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\min ", "", NULL);
}


void latex_menu_on_math_func_sec (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\sec ", "", NULL);
}


void latex_menu_on_math_func_sin (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\sin ", "", NULL);
}


void latex_menu_on_math_func_sinh (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\sinh ", "", NULL);
}


void latex_menu_on_math_func_sup (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\sup ", "", NULL);
}


void latex_menu_on_math_func_tan (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\tan ", "", NULL);
}


void latex_menu_on_math_func_tanh (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\tanh ", "", NULL);
}


void latex_menu_on_math_font_style_rm (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\mathrm{", "}", NULL);
}


void latex_menu_on_math_font_style_it (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\mathit{", "}", NULL);
}


void latex_menu_on_math_font_style_bf (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\mathbf{", "}", NULL);
}


void latex_menu_on_math_font_style_sf (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\mathsf{", "}", NULL);
}


void latex_menu_on_math_font_style_tt (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\mathtt{", "}", NULL);
}


void latex_menu_on_math_font_style_cal (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\mathcal{", "}", NULL);
}


void latex_menu_on_math_font_style_bb (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\mathbb{", "}", NULL);
}


void latex_menu_on_math_font_style_frak (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\mathfrak{", "}", NULL);
}


void latex_menu_on_math_accent_acute (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\acute{", "}", NULL);
}


void latex_menu_on_math_accent_grave (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\grave{", "}", NULL);
}


void latex_menu_on_math_accent_tilde (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\tilde{", "}", NULL);
}


void latex_menu_on_math_accent_bar (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\bar{", "}", NULL);
}


void latex_menu_on_math_accent_vec (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\vec{", "}", NULL);
}


void latex_menu_on_math_accent_hat (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\hat{", "}", NULL);
}


void latex_menu_on_math_accent_check (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\check{", "}", NULL);
}


void latex_menu_on_math_accent_breve (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\breve{", "}", NULL);
}


void latex_menu_on_math_accent_dot (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\dot{", "}", NULL);
}


void latex_menu_on_math_accent_ddot (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\ddot{", "}", NULL);
}


void latex_menu_on_math_accent_ring (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\mathring{", "}", NULL);
}


void latex_menu_on_math_space_small (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\, ", "", NULL);
}


void latex_menu_on_math_space_medium (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\: ", "", NULL);
}


void latex_menu_on_math_space_large (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\; ", "", NULL);
}


void latex_menu_on_math_space_quad (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\quad ", "", NULL);
}


void latex_menu_on_math_space_qquad (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\qquad ", "", NULL);
}


void latex_menu_on_math_left_delimiter_1 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\left( ", "", NULL);
}


void latex_menu_on_math_left_delimiter_2 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\left[ ", "", NULL);
}


void latex_menu_on_math_left_delimiter_3 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\left\\lbrace ", "", NULL);
}


void latex_menu_on_math_left_delimiter_4 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\left\\langle ", "", NULL);
}


void latex_menu_on_math_left_delimiter_5 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\left) ", "", NULL);
}


void latex_menu_on_math_left_delimiter_6 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\left] ", "", NULL);
}


void latex_menu_on_math_left_delimiter_7 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\left\\rbrace ", "", NULL);
}


void latex_menu_on_math_left_delimiter_8 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\left\\rangle ", "", NULL);
}


void latex_menu_on_math_left_delimiter_9 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\left. ", "", NULL);
}


void latex_menu_on_math_right_delimiter_1 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\right) ", "", NULL);
}


void latex_menu_on_math_right_delimiter_2 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\right] ", "", NULL);
}


void latex_menu_on_math_right_delimiter_3 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\right\\rbrace ", "", NULL);
}


void latex_menu_on_math_right_delimiter_4 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\right\\rangle ", "", NULL);
}


void latex_menu_on_math_right_delimiter_5 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\right( ", "", NULL);
}


void latex_menu_on_math_right_delimiter_6 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\right[ ", "", NULL);
}


void latex_menu_on_math_right_delimiter_7 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\right\\lbrace ", "", NULL);
}


void latex_menu_on_math_right_delimiter_8 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\right\\langle ", "", NULL);
}


void latex_menu_on_math_right_delimiter_9 (LatexMenu* self) {
	g_return_if_fail (self != NULL);
	latex_menu_text_buffer_insert (self, "\\right. ", "", NULL);
}


static void latex_menu_class_init (LatexMenuClass * klass) {
	latex_menu_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (LatexMenuPrivate));
	G_OBJECT_CLASS (klass)->finalize = latex_menu_finalize;
}


static void latex_menu_instance_init (LatexMenu * self) {
	self->priv = LATEX_MENU_GET_PRIVATE (self);
}


static void latex_menu_finalize (GObject* obj) {
	LatexMenu * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LATEX_MENU, LatexMenu);
	G_OBJECT_CLASS (latex_menu_parent_class)->finalize (obj);
}


GType latex_menu_get_type (void) {
	static volatile gsize latex_menu_type_id__volatile = 0;
	if (g_once_init_enter (&latex_menu_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LatexMenuClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) latex_menu_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LatexMenu), 0, (GInstanceInitFunc) latex_menu_instance_init, NULL };
		GType latex_menu_type_id;
		latex_menu_type_id = g_type_register_static (GTK_TYPE_ACTION_GROUP, "LatexMenu", &g_define_type_info, 0);
		g_once_init_leave (&latex_menu_type_id__volatile, latex_menu_type_id);
	}
	return latex_menu_type_id__volatile;
}



